@@ -1,50 +1,76 @@
-#' Converting values from seconds (s) to gray (Gy)
+#' Converting equivalent dose values from seconds (s) to Gray (Gy)
 #'
-#' Conversion of absorbed radiation dose in seconds (s) to the SI unit gray
+#' Conversion of absorbed radiation dose in seconds (s) to the SI unit Gray
 #' (Gy) including error propagation. Normally used for equivalent dose data.
 #'
-#' Calculation of De values from seconds (s) to gray (Gy) \deqn{De [Gy] = De
-#' [s] * Dose Rate [Gy/s])} \cr Provided calculation methods for error
-#' calculation: \bold{gaussian} error propagation \cr \deqn{De.error.gray =
-#' \sqrt(dose.rate * De.error.seconds)^2 + (De.seconds * dose.rate.error)^2 ))}
-#' \bold{absolute} error propagation \cr \deqn{De.error.gray = abs(dose.rate *
-#' De.error.seconds) + abs(De.seconds * dose.rate.error)}
+#' Calculation of De values from seconds (s) to Gray (Gy)
 #'
-#' @param data \code{\link{data.frame}} (\bold{required}): input values,
-#' structure: data (\code{values[,1]}) and data error (\code{values [,2]}) are
-#' required
+#' \deqn{De [Gy] = De [s] * Dose Rate [Gy/s])}
 #'
-#' @param dose.rate \code{\linkS4class{RLum.Results}} or \code{\link{data.frame}} or \code{\link{numeric}}
-#' (\bold{required}): \code{RLum.Results} needs to be orginated from the
-#' function \code{\link{calc_SourceDoseRate}}, for \code{vector}dose rate in
-#' Gy/s and dose rate error in Gy/s
+#' Provided calculation error propagation methods for error calculation
+#' (with `'se'` as the standard error and `'DR'` of the dose rate of the beta-source):
 #'
-#' @param method \link{character} (with default): method used for error
-#' calculation (\code{gaussian} or \code{absolute}), see details for further
-#' information
+#' **(1) `omit`** (default)
 #'
-#' @return Returns a \link{data.frame} with converted values.
+#' \deqn{se(De) [Gy] = se(De) [s] * DR [Gy/s]}
 #'
-#' @note If no or a wrong method is given, the execution of the function is
-#' stopped. Furthermore, if a \code{data.frame} is provided for the dose rate values is has to
-#' be of the same length as the data frame provided with the argument \code{data}
+#' In this case the standard error of the dose rate of the beta-source is
+#' treated as systematic (i.e. non-random), it error propagation is omitted.
+#' However, the error must be considered during calculation of the final age.
+#' (cf. Aitken, 1985, pp. 242). This approach can be seen as method (2) (gaussian)
+#' for the case the (random) standard error of the beta-source calibration is
+#' 0. Which particular method is requested depends on the situation and cannot
+#' be prescriptive.
 #'
-#' @section Function version: 0.5.0
+#' **(2) `gaussian`** error propagation
 #'
-#' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
-#' (France),\cr Michael Dietze, GFZ Potsdam (Germany),\cr Margret C. Fuchs, HZDR,
-#' Helmholtz-Institute Freiberg for Resource Technology
-#' (Germany)
+#' \deqn{se(De) [Gy] = \sqrt((DR [Gy/s] * se(De) [s])^2 + (De [s] * se(DR) [Gy/s])^2)}
 #'
-#' @seealso #
+#' Applicable under the assumption that errors of `De` and `se` are uncorrelated.
 #'
-#' @references #
+#' **(3) `absolute`** error propagation
+#'
+#' \deqn{se(De) [Gy]= abs(DR [Gy/s] * se(De) [s]) + abs(De [s] * se(DR) [Gy/s])}
+#'
+#' Applicable under the assumption that errors of `De` and `se` are correlated.
+#'
+#'
+#' @param data [data.frame] (**required**):
+#' input values, structure: data (`values[,1]`) and data error (`values [,2]`)
+#' are required
+#'
+#' @param dose.rate [RLum.Results-class], [data.frame] or [numeric] (**required**):
+#' `RLum.Results` needs to be originated from the function [calc_SourceDoseRate],
+#' for `vector` dose rate in Gy/s and dose rate error in Gy/s
+#'
+#' @param error.propagation [character] (*with default*):
+#' error propagation method used for error calculation (`omit`, `gaussian` or
+#' `absolute`), see details for further information
+#'
+#' @return
+#' Returns a [data.frame] with converted values.
+#'
+#' @note
+#' If no or a wrong error propagation method is given, the execution of the function is
+#' stopped. Furthermore, if a `data.frame` is provided for the dose rate values is has to
+#' be of the same length as the data frame provided with the argument `data`
+#'
+#' @section Function version: 0.6.0
+#'
+#' @author
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)\cr
+#' Michael Dietze, GFZ Potsdam (Germany)\cr
+#' Margret C. Fuchs, HZDR, Helmholtz-Institute Freiberg for Resource Technology (Germany)
+#'
+#' @seealso [calc_SourceDoseRate]
+#'
+#' @references
+#' Aitken, M.J., 1985. Thermoluminescence dating. Academic Press.
 #'
 #' @keywords manip
 #'
 #' @examples
 #'
-#'
 #' ##(A) for known source dose rate at date of measurement
 #' ## - load De data from the example data help file
 #' data(ExampleData.DeValues, envir = environment())
@@ -67,17 +93,18 @@
 #' # apply dose.rate to convert De(s) to De(Gy)
 #' Second2Gray(ExampleData.DeValues$BT998, dose.rate)
 #'
-#'
+#' @md
+#' @export
 Second2Gray <- function(
   data,
   dose.rate,
-  method = "gaussian"
+  error.propagation = "omit"
 ){
 
   # Integrity tests -----------------------------------------------------------------------------
 
   ##(1) data.frame or RLum.Data.Curve object?
-  if(is(data, "data.frame") == FALSE){
+  if(!is(data, "data.frame")){
 
     stop("[Second2Gray()] 'data' object has to be of type 'data.frame'!")
 
@@ -108,7 +135,7 @@ Second2Gray <- function(
 
     if(dose.rate@originator != "calc_SourceDoseRate"){
 
-      stop("[Second2Gray()]  Wrong originator for dose.rate 'RLum.Results' object.")
+      stop("[Second2Gray()] Wrong originator for dose.rate 'RLum.Results' object.")
 
     }else{
 
@@ -148,8 +175,17 @@ Second2Gray <- function(
 
   }
 
+  if(error.propagation == "omit"){
 
-  if(method == "gaussian"){
+    if(is(dose.rate,"data.frame")){
+      De.error.gray <- round(dose.rate[,1]*De.error.seconds, digits=3)
+
+    }else{
+      De.error.gray <- round(dose.rate[1]*De.error.seconds, digits=3)
+
+    }
+
+  }else if(error.propagation == "gaussian"){
 
     if(is(dose.rate,"data.frame")){
        De.error.gray <- round(sqrt((De.seconds*dose.rate[,2])^2+(dose.rate[,1]*De.error.seconds)^2), digits=3)
@@ -159,7 +195,7 @@ Second2Gray <- function(
 
     }
 
-  }else if (method == "absolute"){
+  }else if (error.propagation == "absolute"){
 
     if(is(dose.rate,"data.frame")){
       De.error.gray <- round(abs(dose.rate[,1] * De.error.seconds) + abs(De.seconds * dose.rate[,2]), digits=3)
@@ -171,12 +207,15 @@ Second2Gray <- function(
 
   }else{
 
-    stop("[Second2Gray()] unsupported error calculation method!" )
+    stop("[Second2Gray()] unsupported error propagation method!" )
 
   }
 
+  # Return --------------------------------------------------------------------------------------
+
   data <- data.frame(De=De.gray, De.error=De.error.gray)
 
+
   return(data)
 
 }
