@@ -75,7 +75,7 @@
 #' @section Function version: 0.3.0
 #'
 #' @author
-#' Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
 #' @seealso [calc_TLLxTxRatio], [plot_GrowthCurve], [RLum.Analysis-class],
 #' [RLum.Results-class], [get_RLum]
@@ -121,11 +121,14 @@ analyse_SAR.TL <- function(
   ...
 ){
 
+  if (missing("object")) {
+    stop("[analyse_SAR.TL()] No value set for 'object'!", call. = FALSE)
+  }
 
   # Self-call -----------------------------------------------------------------------------------
   if(inherits(object, "list")){
    if(!all(sapply(object, class) == "RLum.Analysis"))
-     stop("[analyse_SAR.TL()] All elements in the input list need to be of class 'RLum.Analysis'!",
+     stop("[analyse_SAR.TL()] All elements in the input list must be of class 'RLum.Analysis'!",
           call. = FALSE)
 
     ##run sequence
@@ -160,24 +163,14 @@ analyse_SAR.TL <- function(
   ##=============================================================================#
   # General Integrity Checks ---------------------------------------------------
 
-  ##GENERAL
-
-  ##MISSING INPUT
-  if(missing("object")==TRUE){
-    stop("[analyse_SAR.TL()] No value set for 'object'!", call. = FALSE)
+  if (!is(object, "RLum.Analysis")) {
+    .throw_error("Input object is not of type 'RLum.Analyis'")
   }
-
-  if(missing("signal.integral.min") == TRUE){
-    stop("[analyse_SAR.TL()] No value set for 'signal.integral.min'!", call. = FALSE)
+  if (missing("signal.integral.min")) {
+    .throw_error("No value set for 'signal.integral.min'")
   }
-
-  if(missing("signal.integral.max") == TRUE){
-    stop("[analyse_SAR.TL()] No value set for 'signal.integral.max'!", call. = FALSE)
-  }
-
-  ##INPUT OBJECTS
-  if(is(object, "RLum.Analysis") == FALSE){
-    stop("[analyse_SAR.TL()] Input object is not of type 'RLum.Analyis'!", call. = FALSE)
+  if (missing("signal.integral.max")) {
+    .throw_error("No value set for 'signal.integral.max'")
   }
 
 
@@ -191,7 +184,7 @@ analyse_SAR.TL <- function(
   ##set vector for sequence structure
   temp.protocol.step <- rep(sequence.structure,length(object@records))[1:length(object@records)]
 
-  ##grep object strucute
+  ## grep object structure
   temp.sequence.structure <- structure_RLum(object)
 
   ##set values for step
@@ -200,27 +193,20 @@ analyse_SAR.TL <- function(
   ##remove TL curves which are excluded
   temp.sequence.structure <- temp.sequence.structure[which(
     temp.sequence.structure[,"protocol.step"]!="EXCLUDE"),]
-
   ##check integrity; signal and bg range should be equal
   if(length(
     unique(
       temp.sequence.structure[temp.sequence.structure[,"protocol.step"]=="SIGNAL","n.channels"]))>1){
 
-    stop(paste(
-      "[analyse_SAR.TL()] Signal range differs. Check sequence structure.\n",
-      temp.sequence.structure
-    ))
+    .throw_error("Signal range differs, check sequence structure.\n",
+                 temp.sequence.structure)
   }
 
   ##check if the wanted curves are a multiple of the structure
-  if(length(temp.sequence.structure[,"id"])%%length(sequence.structure)!=0){
-    stop("[analyse_SAR.TL()] Input TL curves are not a multiple of the sequence structure.")
-
-  }
-
+  if(length(temp.sequence.structure[,"id"])%%length(sequence.structure)!=0)
+    .throw_error("Input TL curves are not a multiple of the sequence structure")
 
   # # Calculate LnLxTnTx values  --------------------------------------------------
-
   ##grep IDs for signal and background curves
   TL.preheat.ID <- temp.sequence.structure[
     temp.sequence.structure[,"protocol.step"] == "PREHEAT","id"]
@@ -324,9 +310,7 @@ analyse_SAR.TL <- function(
   LnLxTnTx[,"Name"]<-as.character(LnLxTnTx[,"Name"])
 
   # Calculate Recycling Ratio -----------------------------------------------
-
-  ##Calculate Recycling Ratio
-
+  RecyclingRatio <- NA
   if(length(LnLxTnTx[LnLxTnTx[,"Repeated"]==TRUE,"Repeated"])>0){
 
     ##identify repeated doses
@@ -354,19 +338,14 @@ analyse_SAR.TL <- function(
     ##Just transform the matrix and add column names
     RecyclingRatio<-t(RecyclingRatio)
     colnames(RecyclingRatio)<-temp.ColNames
-
-  }else{RecyclingRatio<-NA}
-
+  }
 
   # Calculate Recuperation Rate ---------------------------------------------
-
-
-  ##Recuperation Rate
+  Recuperation <- NA
   if("R0" %in% LnLxTnTx[,"Name"]==TRUE){
     Recuperation<-round(LnLxTnTx[LnLxTnTx[,"Name"]=="R0","LxTx"]/
                           LnLxTnTx[LnLxTnTx[,"Name"]=="Natural","LxTx"],digits=4)
-  }else{Recuperation<-NA}
-
+  }
 
   # Combine and Evaluate Rejection Criteria ---------------------------------
 
@@ -426,10 +405,10 @@ analyse_SAR.TL <- function(
                                      object@records[[TL.signal.ID[1]]]@data[signal.integral.max,1])
 
 
-  ##warning if number of curves exceed colour values
+  ## warning if number of curves exceeds colour values
   if(length(col)<length(TL.signal.ID/2)){
-    cat("\n[analyse_SAR.TL.R] Warning: To many curves! Only the first",
-        length(col),"curves are plotted!")
+    message("\n[analyse_SAR.TL.R()] Warning: Too many curves, ",
+            "only the first ", length(col), " curves are plotted")
   }
 
 
@@ -647,8 +626,6 @@ analyse_SAR.TL <- function(
     ##set failed text and mark De as failed
     if (length(grep("FAILED", RejectionCriteria$status)) > 0) {
       mtext("[FAILED]", col = "red")
-
-
     }
   }
 
@@ -682,8 +659,7 @@ analyse_SAR.TL <- function(
 
   }
 
-
-  ##add recjection status
+  ##add rejection status
   if(length(grep("FAILED",RejectionCriteria$status))>0){
     temp.GC <- data.frame(temp.GC, RC.Status="FAILED")
 
@@ -706,4 +682,3 @@ analyse_SAR.TL <- function(
   return(newRLumResults.analyse_SAR.TL)
 
 }
-
