@@ -15,7 +15,7 @@
 #' data. For the Bayesian analysis for each aliquot the following information are needed from the SAR analysis.
 #' `LxTx`, the `LxTx` error and the dose values for all regeneration points.
 #'
-#' **How the systematic error contribution is calculated?**
+#' **How is the systematic error contribution calculated?**
 #'
 #' Standard errors (so far) provided with the source dose rate are considered as systematic uncertainties
 #' and added to final central dose by:
@@ -39,7 +39,7 @@
 #' supports **(a)** either a path to a file or directory or a `list` of file names or paths or
 #' **(b)** a [Risoe.BINfileData-class] object or a list of these objects. The latter one can
 #' be produced by using the function [read_BIN2R], but this function is called automatically
-#' if only a filename and/or a path is provided. In both cases it will become the data that can be
+#' if only a file name and/or a path is provided. In both cases it will become the data that can be
 #' used for the analysis.
 #'
 #' `[XLS_file = NULL]`
@@ -70,7 +70,7 @@
 #'
 #' If an [RLum.Results-class] object is provided as input and(!) this object was
 #' previously created by the function `analyse_baSAR()` itself, the pre-processing part
-#' is skipped and the function starts directly the Bayesian analysis. This option is very powerful
+#' is skipped and the function starts directly with the Bayesian analysis. This option is very powerful
 #' as it allows to change parameters for the Bayesian analysis without the need to repeat
 #' the data pre-processing. If furthermore the argument `aliquot_range` is set, aliquots
 #' can be manually excluded based on previous runs.
@@ -323,7 +323,7 @@
 #'
 #' @author
 #' Norbert Mercier, IRAMAT-CRP2A, Université Bordeaux Montaigne (France) \cr
-#' Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom) \cr
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany) \cr
 #' The underlying Bayesian model based on a contribution by Combès et al., 2015.
 #'
 #' @seealso [read_BIN2R], [calc_OSLLxTxRatio], [plot_GrowthCurve],
@@ -526,26 +526,20 @@ analyse_baSAR <- function(
           data.Lum[,i] <-  c(data.Lum[,i][temp.logic], rep(NA, m))
           data.sLum[,i]  <-  c(data.sLum[,i][temp.logic], rep(NA, m))
 
-          rm(m)
-          rm(temp.logic)
-
+          rm(m, temp.logic)
         }
 
         for (i in 1:Nb_aliquots) {
           Limited_cycles[i] <- length(data.Dose[, i]) - length(which(is.na(data.Dose[, i])))
 
         }
-
       }
 
       ##check and correct for distribution name
-      if(!is.null(baSAR_model)){
-        if(distribution != "user_defined"){
-          distribution <- "user_defined"
-          warning("[analyse_baSAR()] 'distribution' set to 'user_defined'.", call. = FALSE)
-
-        }
-
+      if (!is.null(baSAR_model) && distribution != "user_defined") {
+        distribution <- "user_defined"
+        message("[analyse_basAR()] 'baSAR_model' provided, setting ",
+                "distribution to 'user_defined'")
       }
 
       # Bayesian Models ----------------------------------------------------------------------------
@@ -554,8 +548,7 @@ analyse_baSAR <- function(
       #  > model definition since:
       #  > "The data block is not limited to logical relations, but may also include stochastic relations."
       #  > (Plummer, 2017. JAGS Version 4.3.0 user manual, p. 9)
-      baSAR_model <- list(
-
+      baSAR_models <- list(
         cauchy = "model {
 
             central_D ~  dunif(lower_centralD,upper_centralD)
@@ -585,7 +578,6 @@ analyse_baSAR <- function(
           }",
 
        normal = "model {
-
             central_D ~  dunif(lower_centralD,upper_centralD)
 
             sigma_D ~ dunif(0.01, 1 * central_D)
@@ -613,7 +605,6 @@ analyse_baSAR <- function(
             }",
 
        log_normal = "model {
-
             central_D ~  dunif(lower_centralD,upper_centralD)
 
             log_central_D <-  log(central_D) - 0.5 * l_sigma_D^2
@@ -646,17 +637,19 @@ analyse_baSAR <- function(
        )
 
       ##check whether the input for distribution was sufficient
-      if(!any(distribution%in%names(baSAR_model))){
-        stop(paste0("[analyse_baSAR()] No model is pre-defined for the requested distribution. Please select ", paste(rev(names(baSAR_model))[-1], collapse = ", ")), " or define an own model using the argument 'baSAR_model'!", call. = FALSE)
-
-      }else{
-        if(is.null(baSAR_model)){
-          stop("[analyse_baSAR()] You have specified a 'user_defined' distribution, but you have not provided a model via 'baSAR_model'!", call. = FALSE)
-
-        }
-
+      if (!distribution %in% names(baSAR_models)) {
+        .throw_error("No pre-defined model for the requested distribution. ",
+                     "Please select one of '",
+                     paste(rev(names(baSAR_models))[-1], collapse = "', '"),
+                     "', or define an own model using argument 'baSAR_model'",
+                     nframe = 7)
       }
 
+      if (distribution == "user_defined" && is.null(baSAR_model)) {
+        .throw_error("You specified a 'user_defined' distribution, ",
+                     "but did not provide a model via 'baSAR_model'",
+                     nframe = 7)
+      }
 
       ### Bayesian inputs
       data_Liste  <- list(
@@ -676,27 +669,28 @@ analyse_baSAR <- function(
         cat("\n[analyse_baSAR()] ---- baSAR-model ---- \n")
         cat("\n++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n")
         cat("[analyse_baSAR()] Bayesian analysis in progress ...\n")
-        message(paste(".. >> bounds set to: lower_centralD =", lower_centralD, "| upper_centralD =", upper_centralD))
+        message(".. >> bounds set to: lower_centralD =", lower_centralD,
+                "| upper_centralD =", upper_centralD)
       }
 
       Nb_Iterations <- n.MCMC
 
       if (verbose) {
-        message(paste0(
+        message(
           ".. >> calculation will be done assuming a '",
           distribution,
           "' distribution\n"
-        ))
+        )
       }
 
       ##set model
       jagsfit <- rjags::jags.model(
-          file = textConnection(baSAR_model[[distribution]]),
+          file = textConnection(baSAR_models[[distribution]]),
           data = data_Liste,
           inits = inits,
           n.chains = n.chains,
           n.adapt = Nb_Iterations,
-          quiet = if(verbose){FALSE}else{TRUE}
+          quiet = !verbose
        )
 
       ##update jags model (it is a S3-method)
@@ -774,10 +768,10 @@ analyse_baSAR <- function(
           baSAR.output_summary = baSAR.output,
           baSAR.output_mcmc = sampling,
           models = list(
-            cauchy = baSAR_model[["cauchy"]],
-            normal = baSAR_model[["normal"]],
-            log_normal = baSAR_model[["log_normal"]],
-            user_defined = baSAR_model[["user_defined"]]
+            cauchy = baSAR_models[["cauchy"]],
+            normal = baSAR_models[["normal"]],
+            log_normal = baSAR_models[["log_normal"]],
+            user_defined = baSAR_models[["user_defined"]]
           )
         )
       )
@@ -791,15 +785,23 @@ analyse_baSAR <- function(
   ##check whether rjags is available
   ##code snippet taken from
   ##http://r-pkgs.had.co.nz/description.html
+  # nocov start
   if (!requireNamespace("rjags", quietly = TRUE)) {
-    stop("[analyse_baSAR()] To use this function you have to first install the package 'rjags'.",
-         call. = FALSE)
+    .throw_error("To use this function you have to first install package 'rjags'")
   }
 
   if (!requireNamespace("coda", quietly = TRUE)) {
-    stop("[analyse_baSAR()] To use this function you have to first install the package 'coda'.",
-         call. = FALSE)
+    .throw_error("To use this function you have to first install package 'coda'.")
   }
+  # nocov end
+
+  ## fit.method
+  if (!fit.method %in% c("EXP", "EXP+LIN", "LIN")) {
+    .throw_error("'fit.method' not recognised, supported methods are: ",
+                 "'EXP', 'EXP+LIN' and 'LIN'")
+  }
+
+  .validate_positive_scalar(n.MCMC, int = TRUE)
 
   #capture additional piped arguments
   additional_arguments <- list(
@@ -826,9 +828,8 @@ analyse_baSAR <- function(
     fit.weights = TRUE,
     fit.bounds = TRUE,
     NumberIterations.MC = 100,
-    output.plot = if(plot){TRUE}else{FALSE},
-    output.plotExtended = if(plot){TRUE}else{FALSE}
-
+    output.plot = plot,
+    output.plotExtended = plot
   )
 
   #modify this list on purpose
@@ -838,13 +839,6 @@ analyse_baSAR <- function(
   ##set function arguments
   function_arguments <- NULL
 
-  ##SET fit.method
-  if (fit.method != "EXP" &
-      fit.method != "EXP+LIN" &
-      fit.method != "LIN"){
-
-    stop("[analyse_baSAR()] Unsupported fitting method. Supported: 'EXP', 'EXP+LIN' and 'LIN'", call. = FALSE)
-  }
 
   # Set input -----------------------------------------------------------------------------------
 
@@ -870,11 +864,11 @@ analyse_baSAR <- function(
      ##set Nb_aliquots
      Nb_aliquots <- nrow(object$input_object)
 
-     ##return NULL if not a minium of three aliquots are used for the calculation
+     ## return NULL if not at least three aliquots are used for the calculation
      if(Nb_aliquots < 2){
-       try(stop("[analyse_baSAR()] number of aliquots < 3, this makes no sense, NULL returned!", call. = FALSE))
+       message("[analyse_baSAR()] Error: number of aliquots < 3, ",
+               "this makes no sense, NULL returned")
        return(NULL)
-
      }
 
      ##set variables
@@ -909,8 +903,8 @@ analyse_baSAR <- function(
 
        ##source_doserate
        if(length(as.list(match.call())$source_doserate) > 0){
-         warning("[analyse_baSAR()] Argument 'source_doserate' is ignored in this modus, as it was alreay set.", call. = FALSE)
-
+         .throw_warning("'source_doserate' is ignored in this mode as ",
+                        "it was already set")
        }
 
        ##aliquot_range
@@ -952,8 +946,8 @@ analyse_baSAR <- function(
          Nb_aliquots <- nrow(input_object)
 
        } else{
-         try(stop("[analyse_basAR()] aliquot_range out of bounds! Input ignored!",
-                  call. = FALSE))
+         message("[analyse_basAR()] Error: 'aliquot_range' out of bounds, ",
+                 "input ignored")
 
          ##reset aliquot range
          aliquot_range <- NULL
@@ -973,8 +967,6 @@ analyse_baSAR <- function(
 
        ##set removed aliquots
        removed_aliquots <- object$removed_aliquots
-
-
      }
 
      ##set non function arguments
@@ -985,16 +977,14 @@ analyse_baSAR <- function(
      rm(max_cycles)
 
     }else{
-      stop("[analyse_baSAR()] 'object' is of type 'RLum.Results', but has not been produced by analyse_baSAR()!", call. = FALSE)
-
+      .throw_error("'object' is of type 'RLum.Results', ",
+                   "but was not produced by analyse_baSAR()")
     }
 
-
   }else{
 
     if(verbose){
       cat("\n[analyse_baSAR()] ---- PRE-PROCESSING ----\n")
-
     }
 
 
@@ -1012,55 +1002,54 @@ analyse_baSAR <- function(
     ##In case an RLum.Analysis object is provided we try an ugly conversion only
     if(inherits(object, "list") && all(vapply(object, function(x){inherits(x, "RLum.Analysis")}, logical(1)))){
      if(verbose)
-       cat("[analyse_baSAR()] List of RLum.Analysis-objects detected .. ")
+       cat("[analyse_baSAR()] List of RLum.Analysis-objects detected ..\n")
+
+      ## set number of objects
+      n_objects <- length(object)
 
       ##stop for only one element
-      if(length(object) < 2)
-        stop("[analyse_baSAR()] At least two aliquots are needed for the calculation!", call. = FALSE)
-
-      ##set number of objects
-      if(inherits(object, "list")){
-        n_objects <- length(object)
-
-      }else{
-        n_objects <- 1
-
-      }
+      if (n_objects < 2)
+        .throw_error("At least two aliquots are needed for the calculation")
 
       ##extract wanted curves
       if(verbose)
-        cat("\n\t\t  .. extract 'OSL (UVVIS)' and 'irradiation (NA)'")
+        cat("\t\t  .. extract 'OSL (UVVIS)' and 'irradiation (NA)'\n")
       object <- get_RLum(object, recordType = c("OSL (UVVIS)", "irradiation (NA)"), drop = FALSE)
 
+      ## check that we are not left with empty records
+      if (length(object[[1]]@records) == 0) {
+        .throw_error("No records of the appropriate type were found")
+      }
+
       ##extract irradiation times
       if(is.null(irradiation_times)){
         if(verbose)
-          cat("\n\t\t  .. extract irradiation times")
+          cat("\t\t  .. extract irradiation times\n")
         irradiation_times <- extract_IrradiationTimes(object[[1]])$irr.times$IRR_TIME
-
       }
 
       ##run conversion
       if(verbose)
-        cat("\n\t\t  .. run conversion")
+        cat("\t\t  .. run conversion\n")
       object <- try(convert_RLum2Risoe.BINfileData(object), silent = TRUE)
 
       ##create fallback
        if(inherits(object, "try-error")){
-         stop("[analyse_baSAR()] Object conversion failed. Return NULL!", call. = FALSE)
+         message("[analyse_baSAR()] Error: Object conversion failed, ",
+                 "NULL returned")
          return(NULL)
        }
 
       ##assign irradiation times
       if(is.null(irradiation_times)){
         if(verbose)
-          cat("\n\t\t  .. set irradiation times")
+          cat("\t\t  .. set irradiation times\n")
         object@METADATA[["IRR_TIME"]] <- rep(irradiation_times,n_objects)
       }
 
       ##remove none-OSL curves
       if(verbose && !all("OSL" %in% object@METADATA[["LTYPE"]])){
-        cat("\n\t\t  .. remove non-OSL curves")
+        cat("\t\t  .. remove non-OSL curves\n")
         rm_id <- which(object@METADATA[["LTYPE"]] != "OSL")
         object@METADATA <- object@METADATA[-rm_id,]
         object@DATA[rm_id] <- NULL
@@ -1101,14 +1090,12 @@ analyse_baSAR <- function(
             verbose = verbose
           )
         } else{
-          stop(
-            "[analyse_baSAR()] data type in the input list provided for 'object' is not supported!",
-            call. = FALSE
-          )
+          .throw_error("Unsupported data type in the input list ",
+                       "provided for 'object'")
         }
 
       } else{
-        stop("[analyse_baSAR()] 'object' only accepts a list with objects of similar type!", call. = FALSE)
+        .throw_error("'object' only accepts a list with objects of similar type")
       }
 
     } else if (is(object, "character")) {
@@ -1123,18 +1110,15 @@ analyse_baSAR <- function(
       )
 
     } else{
-      stop(
-        paste0(
-          "[analyse_baSAR()] '",
-          is(object)[1],
-          "' as input is not supported. Check manual for allowed input objects."
-        ), call. = FALSE
-      )
+      .throw_error("'", is(object)[1], "' as input is not supported. ",
+                   "Check manual for allowed input objects.")
     }
 
     ##Problem ... the user might have made a pre-selection in the Analyst software, if this the
     ##we respect this selection
-    if(!all(unlist(lapply(fileBIN.list, FUN = function(x){(x@METADATA[["SEL"]])})))){
+    record.selected <- unlist(lapply(fileBIN.list,
+                                     FUN = function(x) x@METADATA[["SEL"]] ))
+    if (!all(record.selected)) {
 
       fileBIN.list <- lapply(fileBIN.list, function(x){
 
@@ -1146,14 +1130,12 @@ analyse_baSAR <- function(
             x@METADATA[["ID"]] <- 1:nrow(x@METADATA)
             return(x)
 
-
       })
 
       if(verbose){
         cat("\n[analyse_baSAR()] Record pre-selection in BIN-file detected >> record reduced to selection")
 
       }
-
     }
 
     # Declare variables ---------------------------------------------------------------------------
@@ -1185,38 +1167,24 @@ analyse_baSAR <- function(
 
     ##check for duplicated entries; remove them as they would cause a function crash
     if(any(duplicated(unlist(object.file_name)))){
-
+      msg <- paste0("'", paste(
+            object.file_name[which(duplicated(unlist(object.file_name)))],
+            collapse = ", "),
+            "' is a duplicate and therefore removed from the input")
       ##provide messages
       if(verbose){
-        message(paste0(
-          "[analyse_baSAR()] '",
-          paste(
-            object.file_name[which(duplicated(unlist(object.file_name)))],
-            collapse = ", ",
-            "' is a duplicate and therefore removed from the input!"
-          )
-        ))
-
+        message("[analyse_baSAR()] ", msg)
       }
 
-      warning(paste0(
-        "[analyse_baSAR()] '",
-        paste(
-          object.file_name[which(duplicated(unlist(object.file_name)))],
-          collapse = ", ",
-          "' is a duplicate and therefore removed from the input!"
-        )
-      ))
+      .throw_warning(msg)
 
       ##remove entry
       Disc[which(duplicated(unlist(object.file_name)))] <- NULL
       Grain[which(duplicated(unlist(object.file_name)))] <- NULL
       fileBIN.list[which(duplicated(unlist(object.file_name)))] <- NULL
       object.file_name[which(duplicated(unlist(object.file_name)))] <- NULL
-
     }
 
-
   # Expand parameter list -----------------------------------------------------------------------
 
   ##test_parameter = source_doserate
@@ -1227,9 +1195,8 @@ analyse_baSAR <- function(
       source_doserate <- rep(list(source_doserate), length = length(fileBIN.list))
     }
   }else{
-    stop("[analyse_baSAR()] 'source_doserate' is missing, but required as the current implementation expects dose values in Gy!",
-         call. = FALSE)
-
+    .throw_error("'source_doserate' is missing, but the current ",
+                 "implementation expects dose values in Gy")
   }
 
   ##sigmab
@@ -1246,7 +1213,6 @@ analyse_baSAR <- function(
     sig0 <- rep(list(sig0), length = length(fileBIN.list))
   }
 
-
   ##test_parameter = signal.integral
   if(is(signal.integral, "list")){
     signal.integral <- rep(signal.integral, length = length(fileBIN.list))
@@ -1254,7 +1220,6 @@ analyse_baSAR <- function(
     signal.integral <- rep(list(signal.integral), length = length(fileBIN.list))
   }
 
-
   ##test_parameter = signal.integral.Tx
   if (!is.null(signal.integral.Tx)) {
     if (is(signal.integral.Tx, "list")) {
@@ -1271,7 +1236,6 @@ analyse_baSAR <- function(
     background.integral <- rep(list(background.integral), length = length(fileBIN.list))
   }
 
-
   ##test_parameter = background.integral
   if(is(background.integral, "list")){
     background.integral <- rep(background.integral, length = length(fileBIN.list))
@@ -1279,8 +1243,6 @@ analyse_baSAR <- function(
     background.integral <- rep(list(background.integral), length = length(fileBIN.list))
   }
 
-
-
   ##test_parameter = background.integral.Tx
   if (!is.null(background.integral.Tx)) {
     if (is(background.integral.Tx, "list")) {
@@ -1292,19 +1254,15 @@ analyse_baSAR <- function(
     }
   }
 
-
   # Read EXCEL sheet ----------------------------------------------------------------------------
   if(is.null(XLS_file)){
-
     ##select aliquots giving light only, this function accepts also a list as input
     if(verbose){
-      cat("\n[analyse_baSAR()] No XLS-file provided, running automatic grain selection ...")
+      cat("\n[analyse_baSAR()] No XLS-file provided, running automatic grain selection ...\n")
 
     }
 
-
     for (k in 1:length(fileBIN.list)) {
-
       ##if the uses provides only multiple grain data (GRAIN == 0), the verification
       ##here makes not really sense and should be skipped
       if(length(unique(fileBIN.list[[k]]@METADATA[["GRAIN"]])) > 1){
@@ -1316,38 +1274,33 @@ analyse_baSAR <- function(
             cleanup = FALSE
           )
 
-
-        ##remove grain position 0 (this are usually TL measurements on the cup or we are talking about multipe aliquot)
-        if (sum(aliquot_selection$unique_pairs[["GRAIN"]] == 0, na.rm = TRUE) > 0) {
-          warning(
-            paste(
-              "[analyse_baSAR()] Automatic grain selection:",
-              sum(aliquot_selection$unique_pairs[["GRAIN"]] == 0, na.rm = TRUE),
-              "curve(s) with grain index 0 had been removed from the dataset."
-            ),
-            call. = FALSE
-          )
+        ## remove grain position 0 (this are usually TL measurements
+        ## on the cup or we are talking about multiple aliquot)
+        num.grain.pos0 <- sum(aliquot_selection$unique_pairs[["GRAIN"]] == 0,
+                              na.rm = TRUE)
+        if (sum(num.grain.pos0) > 0) {
+          .throw_warning("Automatic grain selection: ", num.grain.pos0,
+                         "curve(s) with grain index 0 had been removed ",
+                         "from the dataset")
         }
 
         datalu <-
           aliquot_selection$unique_pairs[!aliquot_selection$unique_pairs[["GRAIN"]] == 0,]
 
         if(nrow(datalu) == 0){
-
-          try(stop("[analyse_baSAR()] Sorry, nothing was left after the automatic grain selection! NULL returned!", call. = FALSE))
+          message("[analyse_baSAR()] Error: nothing was left after ",
+                  "the automatic grain selection, NULL returned")
           return(NULL)
-
         }
 
       }else{
-
-          warning("[analyse_baSAR()] Only multiple grain data provided, automatic selection skipped!", call. = FALSE)
+          .throw_warning("Only multiple grain data provided, ",
+                         "automatic selection skipped")
           datalu <- unique(fileBIN.list[[k]]@METADATA[, c("POSITION", "GRAIN")])
 
           ##set mono grain to FALSE
           Mono_grain <- FALSE
           aliquot_selection <- NA
-
       }
 
       ##get number of aliquots (one aliquot has a position and a grain number)
@@ -1363,13 +1316,11 @@ analyse_baSAR <- function(
     rm(k)
 
   } else if (is(XLS_file, "data.frame") || is(XLS_file, "character")) {
-
     ##load file if we have an XLS file
     if (is(XLS_file, "character")) {
       ##test for valid file
       if(!file.exists(XLS_file)){
-        stop("[analyse_baSAR()] XLS_file does not exist!", call. = FALSE)
-
+        .throw_error("XLS_file does not exist")
       }
 
       ##import Excel sheet
@@ -1378,29 +1329,32 @@ analyse_baSAR <- function(
         sheet = additional_arguments$sheet,
         col_names = additional_arguments$col_names,
         col_types = additional_arguments$col_types,
-        skip = additional_arguments$skip
+        skip = additional_arguments$skip,
+        progress = FALSE,
       ), stringsAsFactors = FALSE)
 
       ###check whether data format is somehow odd, check only the first three columns
+      if (ncol(datalu) < 3) {
+        .throw_error("The XLS_file requires at least 3 columns for ",
+                     "'BIN_file', 'DISC' and 'GRAIN'")
+      }
       if(!all(grepl(colnames(datalu), pattern = " ")[1:3])){
-        stop("[analyse_baSAR()] One of the first three columns in your XLS_file has no column header. Your XLS_file requires
-             at least three columns for 'BIN_file', 'DISC' and 'GRAIN'",
-             call. = FALSE)
-
+        .throw_error("One of the first 3 columns in your XLS_file has no ",
+                     "header. Your XLS_file requires at least 3 columns for ",
+                     "'BIN_file', 'DISC' and 'GRAIN'")
       }
 
       ##get rid of empty rows if the BIN_FILE name column is empty
       datalu <- datalu[!is.na(datalu[[1]]), ]
 
-
     } else{
 
       datalu <- XLS_file
 
       ##check number of number of columns in data.frame
       if(ncol(datalu) < 3){
-        stop("[analyse_baSAR()] The data.frame provided via XLS_file should consist of at least three columns (see manual)!", call. = FALSE)
-
+        .throw_error("The data.frame provided via 'XLS_file' must have ",
+                     "at least 3 columns (see manual)")
       }
 
       ##problem: the first column should be of type character, the others are
@@ -1409,10 +1363,8 @@ analyse_baSAR <- function(
       datalu[[1]] <- as.character(datalu[[1]])
       datalu[[2]] <- as.numeric(datalu[[2]])
       datalu[[3]] <- as.numeric(datalu[[3]])
-
     }
 
-
     ##limit aliquot range
     if (!is.null(aliquot_range)) {
       datalu <- datalu[aliquot_range,]
@@ -1425,23 +1377,12 @@ analyse_baSAR <- function(
     for (nn in 1:length((datalu[, 1]))) {
       if (!is.na(datalu[nn, 1]))  {
 
-        ##check wether one file fits
-        if (any(grepl(
-          pattern = strsplit(
-            x = basename(datalu[nn, 1]),
-            split = ".",
-            fixed = TRUE
-          )[[1]][1],
-          x = unlist(object.file_name)
-        ))) {
-
-          k <- grep(pattern = strsplit(
-            x = basename(datalu[nn, 1]),
-            split = ".",
-            fixed = TRUE
-          )[[1]][1],
-          x = unlist(object.file_name))
-
+        ##check whether one file fits
+        file.basename <- strsplit(basename(datalu[nn, 1]),
+                                  split = ".", fixed = TRUE)[[1]][1]
+        matches <- grep(pattern = file.basename, x = unlist(object.file_name))
+        if (length(matches) > 0) {
+          k <- matches[1]
           nj <- length(Disc[[k]]) + 1
 
           Disc[[k]][nj] <-  as.numeric(datalu[nn, 2])
@@ -1452,17 +1393,14 @@ analyse_baSAR <- function(
           }
 
         }else{
-          warning(
-            paste0("[analyse_baSAR] '", (datalu[nn, 1]), "' not recognized or not loaded; skipped!"),
-            call. = FALSE
-          )
+          .throw_warning("'", datalu[nn, 1], "' not recognised ",
+                         "or not loaded, skipped")
         }
 
-
       } else{
 
         if (Nb_ali == 0) {
-          stop("[analyse_baSAR()] Nb. discs/grains  = 0 !", call. = FALSE)
+          .throw_error("Number of discs/grains = 0")
         }
 
         break()
@@ -1472,27 +1410,28 @@ analyse_baSAR <- function(
     ##if k is NULL it means it was not set so far, so there was
     ##no corresponding BIN-file found
     if(is.null(k)){
-      stop("[analyse_baSAR()] BIN-file names in XLS-file do not fit to the loaded BIN-files!", call. = FALSE)
-
+      .throw_error("BIN-file names in XLS_file do not match the loaded ",
+                   "BIN-files")
     }
 
   } else{
-    stop("[analyse_baSAR()] input type for 'XLS_file' not supported!", call. = FALSE)
+    .throw_error("Input type for 'XLS_file' not supported")
   }
 
 
   ###################################### loops on files_number
   for (k in 1:length(fileBIN.list)) {
-
     Disc_Grain.list[[k]] <- list()   # data.file number
-    n_aliquots_k <- length((Disc[[k]]))
+    n_aliquots_k <- length(Disc[[k]])
 
       if(n_aliquots_k == 0){
         fileBIN.list[[k]] <- NULL
         if(verbose){
-          message(paste("[analyse_baSAR()] No data has been seletecd from BIN-file", k, ">> BIN-file removed from input!"))
+          message("[analyse_baSAR()] No data has been selected from BIN-file ",
+                  k, " >> BIN-file removed from input!")
         }
-        warning(paste("[analyse_baSAR()] No data has been seletecd from BIN-file", k, ">> BIN-file removed from input!"), call. = FALSE)
+        .throw_warning("No data has been selected from BIN-file ", k,
+                       " >> BIN-file removed from input")
         next()
       }
 
@@ -1546,16 +1485,12 @@ analyse_baSAR <- function(
 
     }else{
       irrad_time.vector <- rep(irradiation_times,n_objects)
-
     }
 
-
     ##if all irradiation times are 0 we should stop here
     if (length(unique(irrad_time.vector)) == 1) {
-      try(stop(
-        "[analyse_baSAR()] It appears the the irradiation times are all the same. Analysis stopped and NULL returned!",
-        call. = FALSE
-      ))
+      message("[analyse_baSAR()] Error: all irradiation times are identical, ",
+              "NULL returned")
       return(NULL)
     }
 
@@ -1573,18 +1508,11 @@ analyse_baSAR <- function(
 
          ##disc (position)
          disc_logic <- (disc_selected == measured_discs.vector)
-
-          if (!any(disc_logic)) {
-            try(stop(
-              paste0(
-                "[analyse_baSAR()] In BIN-file '",
-                unique(fileBIN.list[[k]]@METADATA[["FNAME"]]),
-                "' position number ",
-                disc_selected,
-                " does not exist! NULL returned!"
-              ),
-              call. = FALSE
-            ))
+         if (!any(disc_logic)) {
+            message("[analyse_baSAR()] In BIN-file '",
+                    unique(fileBIN.list[[k]]@METADATA[["FNAME"]]),
+                    "' position number ", disc_selected,
+                    " does not exist, NULL returned")
             return(NULL)
           }
 
@@ -1592,16 +1520,10 @@ analyse_baSAR <- function(
           grain_logic <- (grain_selected == measured_grains.vector)
 
           if (!any(grain_logic)) {
-            try(stop(
-              paste0(
-                "[analyse_baSAR()] In BIN-file '",
-                unique(fileBIN.list[[k]]@METADATA[["FNAME"]]),
-                "' grain number ",
-                grain_selected,
-                " does not exist! NULL returned!"
-              ),
-              call. = FALSE
-            ))
+            message("[analyse_baSAR()] In BIN-file '",
+                    unique(fileBIN.list[[k]]@METADATA[["FNAME"]]),
+                    "' grain number ", grain_selected,
+                    " does not exist, NULL returned")
             return(NULL)
           }
 
@@ -1627,11 +1549,8 @@ analyse_baSAR <- function(
               Disc_Grain.list[[k]][[disc_selected]][[grain_selected]][[1]][s] <- n_index.vector[t]  # indexes
               if ( s%%2 == 1) { Disc_Grain.list[[k]][[disc_selected]][[grain_selected]][[2]][as.integer(1+s/2)] <- dose.value  }      # irradiation doses
 
-
           }
     }
-
-
   }
 
 
@@ -1649,7 +1568,7 @@ analyse_baSAR <- function(
     ##we want to plot the Ln and Tn curves to get a better feeling
     ##The approach here is rather rough coded, but it works
     if (plot) {
-      curve_index <- vapply((1:length(Disc[[k]])), function(i) {
+      curve_index <- vapply(1:length(Disc[[k]]), function(i) {
         disc_selected <-  as.integer(Disc[[k]][i])
         if (Mono_grain == TRUE) {
           grain_selected <- as.integer(Grain[[k]][i])
@@ -1789,7 +1708,6 @@ analyse_baSAR <- function(
         rm(temp_LxTx)
       }
 
-
       # Fitting Growth curve and Plot
       sample_dose <-  unlist(Disc_Grain.list[[k]][[disc_selected]][[grain_selected]][[2]])
       sample_LxTx <-  unlist(Disc_Grain.list[[k]][[disc_selected]][[grain_selected]][[3]])
@@ -1800,7 +1718,6 @@ analyse_baSAR <- function(
       ##create needed data.frame (this way to make sure that rows are doubled if something is missing)
       selected_sample <- as.data.frame(cbind(sample_dose, sample_LxTx, sample_sLxTx, TnTx))
 
-      print(additional_arguments)
       ##call plot_GrowthCurve() to get De and De value
       fitcurve <-
         suppressWarnings(plot_GrowthCurve(
@@ -1864,12 +1781,10 @@ analyse_baSAR <- function(
     w_table_names <- names(w_table)
 
     for(w in 1:length(w_table)){
-      warning(paste(w_table_names[w], "This warning occurred", w_table[w], "times!"), call. = FALSE)
-
+      .throw_warning(w_table_names[w], " This warning occurred ",
+                     w_table[w], " times")
     }
-    rm(w_table)
-    rm(w_table_names)
-
+    rm(w_table, w_table_names)
   }
   rm(calc_OSLLxTxRatio_warning)
 
@@ -1905,8 +1820,7 @@ analyse_baSAR <- function(
       disc_selected <-  as.numeric(Disc[[k]][i])
 
       if (Mono_grain == TRUE) {
-        grain_selected <-
-          as.numeric(Grain[[k]][i])
+        grain_selected <- as.numeric(Grain[[k]][i])
       } else {
         grain_selected <- 1
       }
@@ -1974,7 +1888,7 @@ analyse_baSAR <- function(
     OUTPUT_results <- OUTPUT_results[!is.na(OUTPUT_results[,2]),]
 
     ##clean up NaN values in the LxTx and corresponding error values
-    ##the transposition of the matrix may increase the performance for very large matricies
+    ##the transposition of the matrix may increase the performance for very large matrices
     OUTPUT_results_reduced <- t(OUTPUT_results)
     selection <- vapply(X = 1:ncol(OUTPUT_results_reduced), FUN = function(x){
         !any(is.nan(OUTPUT_results_reduced[9:(8+3*max_cycles), x]) | is.infinite(OUTPUT_results_reduced[9:(8+3*max_cycles), x]))
@@ -1986,17 +1900,16 @@ analyse_baSAR <- function(
 
     ##finally, check for difference in the number of dose points ... they should be the same
     if(length(unique(OUTPUT_results_reduced[,"CYCLES_NB"])) > 1){
-       warning("[analyse_baSAR()] The number of dose points differs across your data set. Check your data!", call. = FALSE)
-
+      .throw_warning("The number of dose points differs across ",
+                     "your data set. Check your data!")
     }
 
   ##correct number of aliquots if necessary
   if(Nb_aliquots > nrow(OUTPUT_results_reduced)) {
     Nb_aliquots <- nrow(OUTPUT_results_reduced)
-    warning(
-      paste0(
-        "[analyse_baSAR()] 'Nb_aliquots' corrected due to NaN or Inf values in Lx and/or Tx to ", Nb_aliquots, ". You might want to check 'removed_aliquots' in the function output."), call. = FALSE)
-
+    .throw_warning("'Nb_aliquots' corrected due to NaN or Inf values ",
+                   "in Lx and/or Tx to ", Nb_aliquots, ". You might want ",
+                   "to check 'removed_aliquots' in the function output.")
   }
 
   ##Prepare for Bayesian analysis
@@ -2037,14 +1950,12 @@ analyse_baSAR <- function(
     if (is.null(method_control[["upper_centralD"]])) {
       method_control <- c(method_control, upper_centralD = 1000)
 
-
     }else{
       if(distribution == "normal" | distribution == "cauchy" | distribution == "log_normal"){
-        warning("[analyse_baSAR()] You have modified the upper central_D boundary, while applying a predefined model. This is possible but not recommended!", call. = FALSE)
-
+        .throw_warning("You have modified the upper central_D boundary ",
+                       "while applying a predefined model. This is ",
+                       "possible but not recommended!")
       }
-
-
     }
 
     ##we do the same for the lower_centralD, just to have everthing in one place
@@ -2053,18 +1964,17 @@ analyse_baSAR <- function(
 
     }else{
       if(distribution == "normal" | distribution == "cauchy" | distribution == "log_normal"){
-        warning("[analyse_baSAR()] You have modified the lower central_D boundary while applying a predefined model. This is possible but not recommended!", call. = FALSE)
+        .throw_warning("You have modified the lower central_D boundary ",
+                       "while applying a predefined model. This is ",
+                       "possible but not recommended!")
       }
-
     }
 
-
     if(min(input_object[["DE"]][input_object[["DE"]] > 0], na.rm = TRUE) < method_control$lower_centralD |
        max(input_object[["DE"]], na.rm = TRUE) > method_control$upper_centralD){
-
-      warning("[analyse_baSAR()] Your set lower_centralD and/or upper_centralD value seem to do not fit to your input data. This may indicate a wronlgy set 'source_doserate'.", call. = FALSE)
-
-
+      .throw_warning("Your lower_centralD and/or upper_centralD values ",
+                     "seem not to fit to your input data. This may indicate ",
+                     "a wronlgy set 'source_doserate'.")
     }
 
   ##>> try here is much better, as the user might run a very long preprocessing and do not
@@ -2083,7 +1993,7 @@ analyse_baSAR <- function(
       method_control = method_control,
       baSAR_model = baSAR_model,
       verbose = verbose
-    ))
+    ), outFile = stdout()) # redirect error messages so they can be silenced
 
   ##check whether this became NULL
   if(!is(results, "try-error")){
@@ -2102,7 +2012,6 @@ analyse_baSAR <- function(
           source_doserate <- list(source_doserate)
 
         }
-
       }
 
       systematic_error <- unlist(lapply(source_doserate, function(x){
@@ -2116,16 +2025,13 @@ analyse_baSAR <- function(
 
     }else{
       systematic_error <- 0
-
-
     }
 
-
     ##state are warning for very different errors
     if(mean(systematic_error) != systematic_error[1]){
-      warning("[analyse_baSAR()] Provided source dose rate errors differ. The mean was taken, but the calculated
-              systematic error might be not valid!", .call = FALSE)
-
+      .throw_warning("Provided source dose rate errors differ. The mean ",
+                     "was taken, but the calculated systematic error ",
+                     "might not be valid")
     }
 
     ##add to the final de
@@ -2134,11 +2040,8 @@ analyse_baSAR <- function(
     ##consider the case that we get NA and this might be confusing
     if(is.na(DE_FINAL.ERROR)){
       DE_FINAL.ERROR <- results[[1]][["CENTRAL.SD"]]
-
     }
 
-
-
     ##combine
     results[[1]] <- cbind(results[[1]], DE_FINAL = results[[1]][["CENTRAL"]], DE_FINAL.ERROR = DE_FINAL.ERROR)
 
@@ -2146,7 +2049,6 @@ analyse_baSAR <- function(
     results <- NULL
     verbose <- FALSE
     plot <- FALSE
-
   }
 
   # Terminal output -----------------------------------------------------------------------------
@@ -2164,7 +2066,6 @@ analyse_baSAR <- function(
       }else{
         cat(paste0("Number of aliquots used:\t", results[[1]][["NB_ALIQUOTS"]],"/",
                    results[[1]][["NB_ALIQUOTS"]] + nrow(removed_aliquots),"\n"))
-
       }
 
     }else{
@@ -2230,8 +2131,8 @@ analyse_baSAR <- function(
 
       ##show error
       if(is(plot_check, "try-error")){
-        stop("[analyse_baSAR()] Plots for 'central_D' and 'sigma_D' could not be produced. You are probably monitoring the wrong variables!", .call = FALSE)
-
+        .throw_error("Plots for 'central_D' and 'sigma_D' could not be ",
+                     "produced. You are probably monitoring the wrong variables")
       }
 
     }else{
@@ -2270,7 +2171,7 @@ analyse_baSAR <- function(
 
     }, FUN.VALUE = vector(mode = "character", length = 1))
 
-    ##to assure a minium of quality not more then 15 boxes a plotted in each plot
+    ## to assure a minimum of quality not more then 15 boxes are plotted in each plot
     i <- 1
 
     while(i < ncol(plot_matrix)){
@@ -2383,7 +2284,6 @@ analyse_baSAR <- function(
 
       }else{
         fit.method_plot <- fit.method
-
       }
 
        ##open plot area
@@ -2435,8 +2335,8 @@ analyse_baSAR <- function(
 
             }
           }else{
-            try(stop("[analyse_baSAR()] Wrong 'variable.names' monitored, dose responses curves could not be plotted!", call. = FALSE))
-
+            message("[analyse_baSAR()] Error: Wrong 'variable.names' ",
+                    "monitored, dose responses curves could not be plotted")
           }
 
           ##add dose points
