@@ -1,4 +1,4 @@
-#'@title Emission Spectra Conversion from Wavelength to Energy Scales
+#'@title Emission Spectra Conversion from Wavelength to Energy Scales (Jacobian Conversion)
 #'
 #'@description The function provides a convenient and fast way to convert emission spectra wavelength
 #'to energy scales. The function works on [RLum.Data.Spectrum-class], [data.frame] and [matrix] and
@@ -173,7 +173,8 @@ convert_Wavelength2Energy <- function(
 
     #sort values if needed
     if(order){
-      object@data <-  object@data[order(as.numeric(rownames(object@data))),]
+      object@data <- object@data[order(as.numeric(rownames(object@data))), ,
+                                 drop = FALSE]
       rownames(object@data) <- sort(as.numeric(rownames(object@data)))
 
     }
