@@ -1,4 +1,4 @@
-#' Nonlinear Least Squares Fit for CW-OSL curves `[beta version]`
+#' Nonlinear Least Squares Fit for CW-OSL curves -beta version-
 #'
 #' The function determines the weighted least-squares estimates of the
 #' component parameters of a CW-OSL signal for a given maximum number of
@@ -7,30 +7,30 @@
 #'
 #' **Fitting function**
 #'
-#' The function for the CW-OSL fitting has the general form: 
-#' 
-#' \deqn{y = I0_{1}*\lambda_{1}*exp(-\lambda_1*x) + ,\ldots, + I0_{i}*\lambda_{i}*exp(-\lambda_i*x) } 
-#' 
+#' The function for the CW-OSL fitting has the general form:
+#'
+#' \deqn{y = I0_{1}*\lambda_{1}*exp(-\lambda_1*x) + ,\ldots, + I0_{i}*\lambda_{i}*exp(-\lambda_i*x) }
+#'
 #' where \eqn{0 < i < 8}
-#' 
+#'
 #' and \eqn{\lambda} is the decay constant \cr
-#' and \eqn{I0} the intial number of trapped electrons.
-#' 
+#' and \eqn{I0} the initial number of trapped electrons.
+#'
 #' *(for the used equation cf. Boetter-Jensen et al., 2003, Eq. 2.31)*
 #'
 #' **Start values**
 #'
 #' Start values are estimated automatically by fitting a linear function to the
 #' logarithmized input data set. Currently, there is no option to manually
-#' provide start parameters. 
+#' provide start parameters.
 #'
 #' **Goodness of fit**
 #'
 #' The goodness of the fit is given as pseudoR^2 value (pseudo coefficient of
 #' determination). According to Lave (1970), the value is calculated as:
-#' 
-#' \deqn{pseudoR^2 = 1 - RSS/TSS} 
-#' 
+#'
+#' \deqn{pseudoR^2 = 1 - RSS/TSS}
+#'
 #' where \eqn{RSS = Residual~Sum~of~Squares} \cr
 #' and \eqn{TSS = Total~Sum~of~Squares}
 #'
@@ -39,114 +39,103 @@
 #' **Error of fitted component parameters**
 #'
 #' The 1-sigma error for the
-#' components is calculated using the function [confint]. Due to
-#' considerable calculation time, this option is deactived by default. In
+#' components is calculated using the function [stats::confint]. Due to
+#' considerable calculation time, this option is deactivated by default. In
 #' addition, the error for the components can be estimated by using internal R
 #' functions like [summary]. See the [nls] help page
 #' for more information.
 #'
 #' *For details on the nonlinear regression in R, see Ritz & Streibig (2008).*
 #'
-#' @param values [RLum.Data.Curve-class] or [data.frame] (**required**): 
+#' @param values [RLum.Data.Curve-class] or [data.frame] (**required**):
 #' x, y data of measured values (time and counts). See examples.
-#' 
-#' @param n.components.max [vector] (*optional*): 
-#' maximum number of components that are to be used for fitting. 
+#'
+#' @param n.components.max [vector] (*optional*):
+#' maximum number of components that are to be used for fitting.
 #' The upper limit is 7.
-#' 
-#' @param fit.failure_threshold [vector] (*with default*): 
+#'
+#' @param fit.failure_threshold [vector] (*with default*):
 #' limits the failed fitting attempts.
-#' 
-#' @param fit.method [character] (*with default*): 
+#'
+#' @param fit.method [character] (*with default*):
 #' select fit method, allowed values: `'port'` and `'LM'`. `'port'` uses the 'port'
-#' routine usint the funtion [nls] `'LM'` utilises the function `nlsLM` from 
+#' routine from the function [nls] `'LM'` utilises the function `nlsLM` from
 #' the package `minpack.lm` and with that the Levenberg-Marquardt algorithm.
-#' 
-#' @param fit.trace [logical] (*with default*): 
+#'
+#' @param fit.trace [logical] (*with default*):
 #' traces the fitting process on the terminal.
-#' 
-#' @param fit.calcError [logical] (*with default*): 
-#' calculate 1-sigma error range of components using [confint]
-#' 
-#' @param LED.power [numeric] (*with default*): 
-#' LED power (max.) used for intensity ramping in mW/cm^2. 
-#' **Note:** The value is used for the calculation of the absolute 
+#'
+#' @param fit.calcError [logical] (*with default*):
+#' calculate 1-sigma error range of components using [stats::confint]
+#'
+#' @param LED.power [numeric] (*with default*):
+#' LED power (max.) used for intensity ramping in mW/cm^2.
+#' **Note:** The value is used for the calculation of the absolute
 #' photoionisation cross section.
-#' 
-#' @param LED.wavelength [numeric] (*with default*): 
-#' LED wavelength used for stimulation in nm. 
-#' **Note:** The value is used for the calculation of the absolute 
+#'
+#' @param LED.wavelength [numeric] (*with default*):
+#' LED wavelength used for stimulation in nm.
+#' **Note:** The value is used for the calculation of the absolute
 #' photoionisation cross section.
-#' 
-#' @param cex.global [numeric] (*with default*): 
+#'
+#' @param cex.global [numeric] (*with default*):
 #' global scaling factor.
-#' 
-#' @param sample_code [character] (*optional*): 
-#' sample code used for the plot and the optional output table (mtext).
-#' 
-#' @param output.path [character] (*optional*): 
-#' output path for table output containing the results of the fit. The file 
-#' name is set automatically. If the file already exists in the directory,
-#' the values are appended.
-#' 
-#' @param output.terminal [logical] (*with default*): 
-#' terminal ouput with fitting results.
-#' 
-#' @param output.terminalAdvanced [logical] (*with default*): 
-#' enhanced terminal output. Requires `output.terminal = TRUE`. 
+#'
+#' @param sample_code [character] (*optional*):
+#' sample code used for the plot and the optional output table (`mtext`).
+#'
+#' @param output.terminal [logical] (*with default*):
+#' terminal output with fitting results.
+#'
+#' @param output.terminalAdvanced [logical] (*with default*):
+#' enhanced terminal output. Requires `output.terminal = TRUE`.
 #' If `output.terminal = FALSE` no advanced output is possible.
-#' 
-#' @param plot [logical] (*with default*): 
+#'
+#' @param plot [logical] (*with default*):
 #' returns a plot of the fitted curves.
-#' 
+#'
 #' @param ... further arguments and graphical parameters passed to [plot].
-#' 
-#' @return 
+#'
+#' @return
 #' **plot (*optional*)**
-#' 
+#'
 #' the fitted CW-OSL curves are returned as plot.
-#' 
-#' **table (*optional*)** 
-#' 
-#' an output table (*.csv) with parameters of the fitted components is 
-#' provided if the `output.path` is set.
-#' 
-#' 
+#'
 #' **RLum.Results**
-#'  
-#' Beside the plot and table output options, an [RLum.Results-class] object is 
+#'
+#' Beside the plot and table output options, an [RLum.Results-class] object is
 #' returned.
 #'
 #' `fit`:
 #' an `nls` object (`$fit`) for which generic R functions are
-#' provided, e.g. [summary], [confint], [profile]. For more
+#' provided, e.g. [summary], [stats::confint], [profile]. For more
 #' details, see [nls].
 #'
-#' `output.table`: 
+#' `output.table`:
 #' a [data.frame] containing the summarised parameters including the error
-#' 
-#' `component.contribution.matrix`: 
+#'
+#' `component.contribution.matrix`:
 #' [matrix] containing the values for the component to sum contribution plot
 #' (`$component.contribution.matrix`).
 #'
-#' Matrix structure:\cr 
+#' Matrix structure:\cr
 #' Column 1 and 2: time and `rev(time)` values \cr
 #' Additional columns are used for the components, two for each component,
 #' containing I0 and n0. The last columns `cont.` provide information on
 #' the relative component contribution for each time interval including the row
 #' sum for this values.
-#' 
+#'
 #' **object**
-#' 
-#' beside the plot and table output options, an [RLum.Results-class] object 
+#'
+#' beside the plot and table output options, an [RLum.Results-class] object
 #' is returned.
 #'
-#' `fit`: 
+#' `fit`:
 #' an `nls` object (`$fit`) for which generic R functions
 #' are provided, e.g. [summary], [confint], [profile]. For more
 #' details, see [nls].
 #'
-#' `output.table`: 
+#' `output.table`:
 #' a [data.frame] containing the summarised parameters including the error\cr
 #' `component.contribution.matrix`: [matrix] containing the values
 #' for the component to sum contribution plot (`$component.contribution.matrix`).\cr
@@ -157,10 +146,10 @@
 #' containing I0 and n0. The last columns `cont.` provide information on
 #' the relative component contribution for each time interval including the row
 #' sum for this values.
-#' 
-#' 
-#' @note 
-#' 
+#'
+#'
+#' @note
+#'
 #' **Beta version - This function has not been properly tested yet and**
 #' **should therefore not be used for publication purposes!**
 #'
@@ -168,18 +157,18 @@
 #' fit. The trade off between the `n.components` and the pseudo-R^2 value
 #' is currently not considered.
 #'
-#' The function **does not** ensure that the fitting procedure has reached a 
+#' The function **does not** ensure that the fitting procedure has reached a
 #' global minimum rather than a local minimum!
 #'
-#' @section Function version: 0.5.2
+#' @section Function version: 0.5.3
 #'
-#' @author 
-#' Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
+#' @author
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
-#' @seealso [fit_LMCurve], [plot],[nls], [RLum.Data.Curve-class], 
+#' @seealso [fit_LMCurve], [plot],[nls], [RLum.Data.Curve-class],
 #' [RLum.Results-class], [get_RLum], [minpack.lm::nlsLM]
-#' 
-#' @references 
+#'
+#' @references
 #' Boetter-Jensen, L., McKeever, S.W.S., Wintle, A.G., 2003.
 #' Optically Stimulated Luminescence Dosimetry. Elsevier Science B.V.
 #'
@@ -188,9 +177,9 @@
 #'
 #' Ritz, C. & Streibig, J.C., 2008. Nonlinear Regression with R. In: R.
 #' Gentleman, K. Hornik, G. Parmigiani, eds., Springer, p. 150.
-#' 
+#'
 #' @keywords dplot models
-#' 
+#'
 #' @examples
 #'
 #' ##load data
@@ -201,7 +190,7 @@
 #'                    main = "CW Curve Fit",
 #'                    n.components.max = 4,
 #'                    log = "x")
-#'                    
+#'
 #' @md
 #' @export
 fit_CWCurve<- function(
@@ -215,20 +204,16 @@ fit_CWCurve<- function(
   LED.wavelength = 470,
   cex.global = 0.6,
   sample_code = "Default",
-  output.path,
   output.terminal = TRUE,
   output.terminalAdvanced = TRUE,
   plot = TRUE,
   ...
 ){
-  ##TODO
-  ##remove output.path
-
   # INTEGRITY CHECKS --------------------------------------------------------
 
   ##INPUT OBJECTS
   if(is(values, "RLum.Data.Curve") == FALSE & is(values, "data.frame") == FALSE){
-    stop("[fit_CWCurve()] Input object is not of type 'RLum.Data.Curve' or 'data.frame'!", call. = FALSE)
+    .throw_error("Input object is not of type 'RLum.Data.Curve' or 'data.frame'")
   }
 
 
@@ -266,6 +251,8 @@ fit_CWCurve<- function(
   ylab <- if("ylab" %in% names(extraArgs)) {extraArgs$ylab} else
   {paste("OSL [cts/",round(max(x)/length(x), digits = 2)," s]",sep="")}
 
+  if ("output.path" %in% names(extraArgs))
+    .throw_warning("Argument 'output.path' no longer supported, ignored")
 
   ##============================================================================##
   ## FITTING
@@ -280,16 +267,6 @@ fit_CWCurve<- function(
   }
   ##////equation used for fitting///(end)
 
-  ##////equation used for fitting////(start)
-  fit.equation.simple <- function(I0.i,lambda.i){
-    equation<-parse(
-      text=paste("I0[",I0.i,"]*exp(-lambda[",lambda.i,"]*x)",
-                 collapse="+",sep=""))
-    return(equation)
-  }
-  ##////equation used for fitting///(end)
-
-
   ##set formula elements for fitting functions
   ## the upper two funtions should be removed ... but chances are needed ... TODO
   ##////equation used for fitting////(start)
@@ -388,9 +365,7 @@ fit_CWCurve<- function(
       ))#end try
 
     }else{
-
-      stop("[fit_CWCurve()] fit.method unknown.", call. = FALSE)
-
+      .throw_error("'fit.method' unknown")
     }
 
 
@@ -533,7 +508,7 @@ fit_CWCurve<- function(
     pR<-round(1-RSS/TSS,digits=4)
 
     if(pR<0){
-      warning("pseudo-R^2 < 0!")
+      .throw_warning("pseudo-R^2 < 0!")
     }
 
     ## ---------------------------------------------
@@ -635,22 +610,6 @@ fit_CWCurve<- function(
       colnames(output.table)<-c("sample_code","n.components",
                                 output.tableColNames,"pseudo-R^2")
 
-      if(missing(output.path)==FALSE){
-
-        ##write file with just the header if the file not exists
-        if(file.exists(paste(output.path,"fit_CWCurve_Output_",sample_code,".csv",sep=""))==FALSE){
-          write.table(output.table,file=paste(output.path,"fit_CWCurve_Output_",
-                                              sample_code,".csv",sep=""), sep=";"
-                      ,row.names=FALSE)
-        }else{
-          write.table(output.table,file=paste(output.path,"fit_CWCurve_Output_",
-                                              sample_code,".csv",sep=""), sep=";"
-                      ,row.names=FALSE, append=TRUE, col.names=FALSE)
-
-        }#endif::for write option
-
-      }#endif::table output
-
       ##============================================================================##
       ## COMPONENT TO SUM CONTRIBUTION PLOT
       ##============================================================================##
@@ -756,7 +715,7 @@ fit_CWCurve<- function(
 
     if (output.terminal==TRUE)
       writeLines("[fit_CWCurve()] Fitting Error >> Plot without fit produced!")
-    
+
     output.table<-NA
     component.contribution.matrix <- NA
   }
