@@ -5,18 +5,23 @@
 #'
 #' The easiest way to create a user-specific layout definition is perhaps to
 #' create either an empty or a default layout object and fill/modify the
-#' definitions (\code{user.layout <- get_Layout(data = "empty")}).
+#' definitions (`user.layout <- get_Layout(data = "empty")`).
 #'
-#' @param layout \code{\link{character}} or \code{\link{list}} object
-#' (required): name of the layout definition to be returned. If name is
-#' provided the respective definition is returned. One of the following
-#' supported layout definitions is possible: \code{"default"},
-#' \code{"journal.1"}, \code{"small"}, \code{"empty"}. User-specific layout
-#' definitions must be provided as a list object of predefined structure, see
-#' details.
+#' @param layout [character] or [list] object (**required**): 
+#' name of the layout definition to be returned. If name is provided the 
+#' respective definition is returned. One of the following
+#' supported layout definitions is possible: `"default"`,
+#' `"journal.1"`, `"small"`, `"empty"`. 
+#' 
+#' User-specific layout definitions must be provided as a list object of
+#' predefined structure, see details.
+#' 
 #' @return A list object with layout definitions for plot functions.
+#' 
 #' @section Function version: 0.1
+#' 
 #' @author Michael Dietze, GFZ Potsdam (Germany)
+#' 
 #' @examples
 #'
 #' ## read example data set
@@ -40,6 +45,7 @@
 #' plot_AbanicoPlot(data = ExampleData.DeValues,
 #'                  layout = "journal")
 #'
+#' @md
 #' @export
 get_Layout <- function(
   layout
@@ -631,8 +637,8 @@ get_Layout <- function(
         )
       )
     } else {
-      warning("Layout definition not supported! Default layout is used.")
-      
+      .throw_warning("Layout definition not supported, ",
+                     "default layout is used.")
       layout <- get_Layout(layout = "default")
     }
   } else if(is.list(layout) == TRUE) {
@@ -644,4 +650,3 @@ get_Layout <- function(
   ## return layout parameters
   return(layout)
 }
-
