@@ -29,7 +29,8 @@
 #' lower bound of the signal integral.
 #'
 #' @param signal.integral.max [integer] (**required**):
-#' upper bound of the signal integral.
+#' upper bound of the signal integral. Must be strictly greater than
+#' `signal.integral.min`.
 #'
 #' @param background.integral.min [integer] (**required**):
 #' lower bound of the background integral.
@@ -202,18 +203,31 @@ plot_DetPlot <- function(
 # Integrity Tests -----------------------------------------------------------------------------
   ##check input
   if(!inherits(object, "RLum.Analysis"))
-    stop("[plot_DetPlot()] input must be an RLum.Analysis object!", call. = FALSE)
+    .throw_error("Input must be an 'RLum.Analysis' object")
 
   ##get structure
   object.structure <- structure_RLum(object)
 
+  ## signal.integral
+  .validate_positive_scalar(signal.integral.min, int = TRUE)
+  .validate_positive_scalar(signal.integral.max, int = TRUE)
+  if (signal.integral.min >= signal.integral.max) {
+    .throw_error("'signal.integral.max' must be greater than 'signal.integral.min'")
+  }
+
+  ## background.integral
+  .validate_positive_scalar(background.integral.min, int = TRUE)
+  .validate_positive_scalar(background.integral.min, int = TRUE)
+
 # Set parameters ------------------------------------------------------------------------------
   ##set n.channels
   if(is.null(n.channels)){
     n.channels <- ceiling(
       (background.integral.min - 1 - signal.integral.max) / (signal.integral.max - signal.integral.min)
     )
-
+    if (verbose) {
+      message("'n.channels' not specified, set to ", n.channels)
+    }
   }
 
   analyse_function.settings <- list(
@@ -232,17 +246,9 @@ plot_DetPlot <- function(
 # Analyse -------------------------------------------------------------------------------------
   ##set integral sequence
   if (is.null(signal_integral.seq)) {
-    if(signal.integral.min == signal.integral.max){
-      signal_integral.seq <- signal.integral.min:(background.integral.min - 1)
-
-    }else{
-      signal_integral.seq <-
-        seq(signal.integral.min,
-            background.integral.min - 1,
-            by = signal.integral.max - signal.integral.min)
-
-    }
-
+    signal_integral.seq <- seq(signal.integral.min,
+                               background.integral.min - 1,
+                               by = signal.integral.max - signal.integral.min)
   }
 
   if(analyse_function  == "analyse_SAR.CWOSL"){
@@ -262,13 +268,11 @@ plot_DetPlot <- function(
         plot.single = analyse_function.settings$plot.single,
         verbose = verbose
       )
-
     }))
 
-
   }
   else if(analyse_function  == "analyse_pIRIRSequence"){
-    results <- merge_RLum(lapply(1:n.channels, function(x){
+    result.temp.list <- lapply(1:n.channels, function(x) {
       analyse_pIRIRSequence(
         object = object,
         signal.integral.min = if(method == "shift"){signal_integral.seq[x]}else{signal_integral.seq[1]},
@@ -281,17 +285,24 @@ plot_DetPlot <- function(
         plot.single = analyse_function.settings$plot.single,
         sequence.structure = analyse_function.settings$sequence.structure,
         verbose = verbose
-
       )
+    })
 
-    }))
-
-
-
+    ## as the analyse_pIRIRSequence() may fail, we see how many results
+    ## we've actually managed to produce
+    num.valid.results <- sum(!sapply(result.temp.list, is.null))
+    if (num.valid.results == 0) {
+      .throw_error("No valid results produced")
+    }
+    if (num.valid.results == 1) {
+      results <- result.temp.list
+    } else {
+      results <- merge_RLum(result.temp.list)
+    }
+    rm(result.temp.list)
   }
   else{
-   stop("[plot_DetPlot()] 'analyse_function' unknown!", call. = FALSE)
-
+   .throw_error("Unknown 'analyse_function'")
   }
 
 
