@@ -43,8 +43,11 @@
 #' with the appropriate keyword using the argument `summary.method`.
 #'
 #'
-#' @param data [data.frame] or [RLum.Results-class] object (**required**):
-#' for `data.frame`: two columns: De (`values[,1]`) and De error (`values[,2]`).
+#' @param data [data.frame], [vector] or [RLum.Results-class] object (**required**):
+#' for `data.frame`: either two columns: De (`values[,1]`) and De error
+#' (`values[,2]`), or one: De (`values[,1]`). If a numeric vector or a
+#' single-column data frame is provided, De error is assumed to be 10^-9
+#' for all measurements and error bars are not drawn.
 #' For plotting multiple data sets, these must be provided as
 #' `list` (e.g. `list(dataset1, dataset2)`).
 #'
@@ -94,11 +97,11 @@
 #' The plot output is no 'probability density' plot (cf. the discussion
 #' of Berger and Galbraith in Ancient TL; see references)!
 #'
-#' @section Function version: 3.5.7
+#' @section Function version: 3.6.0
 #'
 #' @author
 #' Michael Dietze, GFZ Potsdam (Germany)\cr
-#' Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
+#' Geography & Earth Sciences, Aberystwyth University (United Kingdom)
 #'
 #' @seealso [density], [plot]
 #'
@@ -178,31 +181,34 @@ plot_KDE <- function(
   ## account for depreciated arguments
   if("centrality" %in% names(list(...))) {
     boxplot <- TRUE
-    warning(paste("[plot_KDE()] Argument 'centrality' no longer supported. ",
-                  "Replaced by 'boxplot = TRUE'."))
+    .throw_warning("Argument 'centrality' no longer supported. ",
+                   "Replaced by 'boxplot = TRUE'.")
   }
 
   if("dispersion" %in% names(list(...))) {
     boxplot <- TRUE
-    warning(paste("[plot_KDE()] Argument 'dispersion' no longer supported. ",
-                  "Replaced by 'boxplot = TRUE'."))
+    .throw_warning("Argument 'dispersion' no longer supported. ",
+                   "Replaced by 'boxplot = TRUE'.")
   }
 
   if("polygon.col" %in% names(list(...))) {
     boxplot <- TRUE
-    warning(paste("[plot_KDE()] Argument 'polygon.col' no longer supported. ",
-                  "Replaced by 'boxplot = TRUE'."))
+    .throw_warning("Argument 'polygon.col' no longer supported. ",
+                   "Replaced by 'boxplot = TRUE'.")
   }
 
   if("weights" %in% names(list(...))) {
-    warning(paste("[plot_KDE()] Argument 'weights' no longer supported. ",
-                  "Weights are omitted."))
+    .throw_warning("Argument 'weights' no longer supported. ",
+                   "Weights are omitted.")
+  }
+
+  if (is(data, "list") && length(data) == 0) {
+    .throw_error("'data' is an empty list")
   }
 
   ## Homogenise input data format
   if(is(data, "list") == FALSE) {
     data <- list(data)
-
   }
 
   ## check/adjust input data structure
@@ -210,8 +216,8 @@ plot_KDE <- function(
     if(is(data[[i]], "RLum.Results") == FALSE &
          is(data[[i]], "data.frame") == FALSE &
          is.numeric(data[[i]]) == FALSE) {
-      stop(paste("[plot_KDE()] Input data format is neither",
-                 "'data.frame', 'RLum.Results' nor 'numeric'"), call. = FALSE)
+      .throw_error("Input data must be one of 'data.frame', ",
+                   "'RLum.Results' or 'numeric'")
     } else {
 
       ##extract RLum.Results
@@ -219,38 +225,44 @@ plot_KDE <- function(
         data[[i]] <- get_RLum(data[[i]], "data")[,1:2]
       }
 
-      ##make sure we only take the first two columns
-      data[[i]] <- data[[i]][,1:2]
-
-
-      ##account for very short datasets
-      if(length(data[[i]]) < 2) {
-        data[[i]] <- cbind(data[[i]], rep(NA, length(data[[i]])))
+      ## ensure that the dataset it not degenerate
+      if (NROW(data[[i]]) == 0) {
+       .throw_error("Input data ", i, " has 0 rows")
       }
 
+      ## if `data[[i]]` is a numeric vector or a single-column data frame,
+      ## append a second column with a small non-zero value (10^-9 for
+      ## consistency with what `calc_Statistics() does)
+      if (NCOL(data[[i]]) < 2) {
+        data[[i]] <- data.frame(data[[i]], 10^-9)
+        attr(data[[i]], "De.errors.available") <- FALSE
+      } else {
+        ## keep only the first two columns
+        data[[i]] <- data[[i]][, 1:2]
+        attr(data[[i]], "De.errors.available") <- TRUE
+      }
     }
 
-    ##check for Inf values and remove them if need
-    if(any(is.infinite(unlist(data[[i]])))){
-      Inf_id <- which(is.infinite(unlist(data[[i]]))[1:nrow(data[[i]])/ncol(data[[i]])])
-      warning(paste("[plot_KDE()] Inf values removed in row(s):", paste(Inf_id, collapse = ", "), "in data.frame", i), call. = FALSE)
-      data[[i]] <- data[[i]][-Inf_id,]
-      rm(Inf_id)
+    ## find the index Inf values in each of the two columns and remove the
+    ## corresponding rows if needed
+    inf.idx <- unlist(lapply(data[[i]], function(x) which(is.infinite(x))))
+    if (length(inf.idx) > 0) {
+      inf.row <- sort(unique(inf.idx))
+      .throw_warning("Inf values removed in rows: ",
+                     paste(inf.row, collapse = ", "), " in data.frame ", i)
+      data[[i]] <- data[[i]][-inf.row, ]
+      rm(inf.idx, inf.row)
 
       ##check if empty
       if(nrow(data[[i]]) == 0){
         data[i] <- NULL
-
       }
-
     }
-
   }
 
   ##check if list is empty
   if(length(data) == 0)
-    stop("[plot_KDE()] Your input is empty, intentionally or maybe after Inf removal? Nothing plotted!", call. = FALSE)
-
+    .throw_error("Your input is empty due to Inf removal")
 
   ## check/set function parameters
   if(missing(summary) == TRUE) {
@@ -280,13 +292,16 @@ plot_KDE <- function(
   ## optionally, count and exclude NA values and print result
   if(na.rm == TRUE) {
     for(i in 1:length(data)) {
-      n.NA <- sum(is.na(data[[i]][,1]))
+      na.idx <- which(is.na(data[[i]][, 1]))
+      n.NA <- length(na.idx)
       if(n.NA == 1) {
         message(paste("1 NA value excluded from data set", i, "."))
       } else if(n.NA > 1) {
         message(paste(n.NA, "NA values excluded from data set", i, "."))
       }
-      data[[i]] <- na.exclude(data[[i]])
+      if (n.NA > 0) {
+        data[[i]] <- data[[i]][-na.idx, ]
+      }
     }
   }
 
@@ -336,10 +351,8 @@ plot_KDE <- function(
 
     }else{
       De.density[[length(De.density) + 1]] <- NA
-      warning("[plot_KDE()] Less than 2 points provided, no density plotted.", call. = FALSE)
-
+      .throw_warning("Single data point found, no density calculated")
     }
-
   }
 
   ## remove dummy list element
@@ -370,8 +383,6 @@ plot_KDE <- function(
       De.density.range[i,1:4] <- NA
       De.stats[i,4] <- NA
     }
-
-
   }
 
   ## Get global range of densities
@@ -615,6 +626,9 @@ plot_KDE <- function(
 
   if("ylim" %in% names(list(...))) {
     ylim.plot <- list(...)$ylim
+    if (length(ylim.plot) < 4) {
+      .throw_error("'ylim' must be a vector of length 4")
+    }
   } else {
     if(!is.na(De.density.range[1])){
       ylim.plot <- c(De.density.range[3],
@@ -807,7 +821,7 @@ plot_KDE <- function(
   }
 
   if("fun" %in% names(list(...))) {
-    fun <- list(...)$fun
+    fun <- list(...)$fun # nocov
   } else {
     fun <- FALSE
   }
@@ -1209,15 +1223,16 @@ plot_KDE <- function(
 
     ## add De error bars
     for(i in 1:length(data)) {
-      arrows(data[[i]][,1] - data[[i]][,2]/2,
-             1:length(data[[i]][,1]),
-             data[[i]][,1] + data[[i]][,2]/2,
-             1:length(data[[i]][,1]),
-             code = 3,
-             angle = 90,
-             length = 0.05,
-             col = col.value.bar[i])
-
+      if (attr(data[[i]], "De.errors.available")) {
+        arrows(data[[i]][, 1] - data[[i]][, 2],
+               1:length(data[[i]][,1]),
+               data[[i]][, 1] + data[[i]][, 2],
+               1:length(data[[i]][, 1]),
+               code = 3,
+               angle = 90,
+               length = 0.05,
+               col = col.value.bar[i])
+      }
       ## add De measurements
       points(data[[i]][,1], 1:De.stats[i,1],
              col = col.value.dot[i],
@@ -1239,7 +1254,7 @@ plot_KDE <- function(
        cex.axis = cex)
 
   ## FUN by R Luminescence Team
-  if(fun==TRUE){sTeve()}
+  if (fun == TRUE) sTeve() # nocov
 
   if(output == TRUE) {
     return(invisible(list(De.stats = De.stats,
@@ -1248,4 +1263,3 @@ plot_KDE <- function(
   }
 
 }
-
