@@ -38,7 +38,9 @@
 #' - `"skewness"` (skewness).
 #'
 #' @param data [data.frame] or [RLum.Results-class] object (**required**):
-#' for `data.frame` two columns: De (`data[,1]`) and De error (`data[,2]`).
+#' for `data.frame`: either two columns: De (`data[,1]`) and De error
+#' (`data[,2]`), or one: De (`values[,1]`). If a single-column data frame
+#' is provided, De error is assumed to be 10^-9 for all measurements.
 #' To plot several data sets in one plot, the data sets must be provided as
 #' `list`, e.g. `list(data.1, data.2)`.
 #'
@@ -125,11 +127,11 @@
 #'
 #' @return Returns a plot object.
 #'
-#' @section Function version: 0.5.7
+#' @section Function version: 0.5.9
 #'
 #' @author
 #' Michael Dietze, GFZ Potsdam (Germany)\cr
-#' Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)\cr
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)\cr
 #' Based on a rewritten S script of Rex Galbraith, 2010
 #'
 #' @seealso [plot], [plot_KDE], [plot_Histogram], [plot_AbanicoPlot]
@@ -187,6 +189,7 @@
 #' plot_RadialPlot(
 #'   data = ExampleData.DeValues,
 #'   log.z = FALSE,
+#'   xlim = c(0, 5),
 #'   zlim = c(100, 200))
 #'
 #' ## now the two plots with serious but seasonally changing fun
@@ -288,6 +291,10 @@ plot_RadialPlot <- function(
   output = FALSE,
   ...
 ) {
+  if (is(data, "list") && length(data) == 0) {
+    .throw_error("'data' is an empty list")
+  }
+
   ## Homogenise input data format
   if(is(data, "list") == FALSE) {data <- list(data)}
 
@@ -295,15 +302,26 @@ plot_RadialPlot <- function(
   for(i in 1:length(data)) {
     if(is(data[[i]], "RLum.Results") == FALSE &
          is(data[[i]], "data.frame") == FALSE) {
-      stop(paste("[plot_RadialPlot] Error: Input data format is neither",
-                 "'data.frame' nor 'RLum.Results'"), call. = FALSE)
+      .throw_error("Error: Input data must be 'data.frame' or 'RLum.Results'")
     } else {
       if(is(data[[i]], "RLum.Results") == TRUE) {
         data[[i]] <- get_RLum(data[[i]], "data")
       }
 
-      ##use only the first two columns
-      data[[i]] <- data[[i]][,1:2]
+      ## ensure that the dataset it not degenerate
+      if (nrow(data[[i]]) == 0) {
+       .throw_error("Input data ", i, " has 0 rows")
+      }
+
+      ## if `data[[i]]` is a single-column data frame, append a second
+      ## column with a small non-zero value (10^-9 for consistency with
+      ## what `calc_Statistics() does)
+      if (ncol(data[[i]]) < 2) {
+        data[[i]] <- data.frame(data[[i]], 10^-9)
+      } else if (ncol(data[[i]]) > 2) {
+        ## keep only the first two columns
+        data[[i]] <- data[[i]][, 1:2]
+      }
     }
   }
 
@@ -324,23 +342,14 @@ plot_RadialPlot <- function(
     grid.col <- rep("grey70", length(data))
   }
 
-  if(missing(summary) == TRUE) {
-    summary <- NULL
-  }
-
-  if(missing(summary.pos) == TRUE) {
-    summary.pos <- "topleft"
-  }
-
   if(missing(mtext) == TRUE) {
     mtext <- ""
   }
 
-
   ## check z-axis log-option for grouped data sets
   if(is(data, "list") == TRUE & length(data) > 1 & log.z == FALSE) {
-    warning(paste("Option 'log.z' is not set to 'TRUE' altough more than one",
-                  "data set (group) is provided."))
+    .throw_warning("Option 'log.z' is not set to 'TRUE' altough ",
+                   "more than one data set (group) is provided.")
   }
 
   ## optionally, remove NA-values
@@ -372,12 +381,10 @@ plot_RadialPlot <- function(
   }
 
   ## calculate correction dose to shift negative values
-  if(min(De.global) < 0) {
-
+  if(min(De.global) < 0 && log.z) {
     if("zlim" %in% names(extraArgs)) {
       De.add <- abs(extraArgs$zlim[1])
     } else {
-
       ## estimate delta De to add to all data
       De.add <-  min(10^ceiling(log10(abs(De.global))) * 10)
 
@@ -394,11 +401,9 @@ plot_RadialPlot <- function(
   De.delta <- ticks[2] - ticks[1]
 
   ## optionally add correction dose to data set and adjust error
-  if(log.z == TRUE) {
-
-    for(i in 1:length(data)) {
+  if(log.z) {
+    for(i in 1:length(data))
       data[[i]][,1] <- data[[i]][,1] + De.add
-    }
 
     De.global <- De.global + De.add
 
@@ -419,12 +424,10 @@ plot_RadialPlot <- function(
   De.delta <- ticks[2] - ticks[1]
 
   ## calculate and append statistical measures --------------------------------
-
   ## z-values based on log-option
   z <- lapply(1:length(data), function(x){
     if(log.z == TRUE) {log(data[[x]][,1])} else {data[[x]][,1]}})
 
-  if(is(z, "list") == FALSE) {z <- list(z)}
   data <- lapply(1:length(data), function(x) {
      cbind(data[[x]], z[[x]])})
   rm(z)
@@ -432,7 +435,6 @@ plot_RadialPlot <- function(
   ## calculate se-values based on log-option
   se <- lapply(1:length(data), function(x, De.add){
     if(log.z == TRUE) {
-
       if(De.add != 0) {
         data[[x]][,2] <- data[[x]][,2] / (data[[x]][,1] + De.add)
       } else {
@@ -441,7 +443,7 @@ plot_RadialPlot <- function(
     } else {
       data[[x]][,2]
     }}, De.add = De.add)
-  if(is(se, "list") == FALSE) {se <- list(se)}
+
   data <- lapply(1:length(data), function(x) {
     cbind(data[[x]], se[[x]])})
   rm(se)
@@ -479,8 +481,7 @@ plot_RadialPlot <- function(
     z.central <- lapply(1:length(data), function(x){
       rep(median.w(y = data[[x]][,3],
                    w = data[[x]][,4]), length(data[[x]][,3]))})
-  } else if(is.numeric(centrality) == TRUE &
-              length(centrality) == length(data)) {
+  } else if(is.numeric(centrality) & length(centrality) == length(data)) {
     z.central.raw <- if(log.z == TRUE) {
       log(centrality + De.add)
     } else {
@@ -493,7 +494,7 @@ plot_RadialPlot <- function(
     z.central <- lapply(1:length(data), function(x){
       rep(median(data[[x]][,3], na.rm = TRUE), length(data[[x]][,3]))})
   } else {
-    stop("Measure of centrality not supported!")
+    .throw_error("Measure of centrality not supported")
   }
 
   data <- lapply(1:length(data), function(x) {
@@ -503,7 +504,6 @@ plot_RadialPlot <- function(
   ## calculate precision
   precision <- lapply(1:length(data), function(x){
     1 / data[[x]][,4]})
-  if(is(precision, "list") == FALSE) {precision <- list(precision)}
   data <- lapply(1:length(data), function(x) {
     cbind(data[[x]], precision[[x]])})
   rm(precision)
@@ -511,7 +511,6 @@ plot_RadialPlot <- function(
   ## calculate standard estimate
   std.estimate <- lapply(1:length(data), function(x){
     (data[[x]][,3] - data[[x]][,5]) / data[[x]][,4]})
-  if(is(std.estimate, "list") == FALSE) {std.estimate <- list(std.estimate)}
   data <- lapply(1:length(data), function(x) {
     cbind(data[[x]], std.estimate[[x]])})
 
@@ -565,8 +564,8 @@ if(centrality[1] == "mean") {
       if (df[k] < 0)
         k <- k + 1
       else if (df[k] == 0)
-        return((w[k] * y[k] + w[k - 1] * y[k - 1])/(w[k] +
-                                                      w[k - 1]))
+        return((w[k] * y[k] + w[k - 1] * y[k - 1])/(w[k] + w[k - 1]))
+
       else return(y[k - 1])
     }
   }
@@ -576,9 +575,8 @@ if(centrality[1] == "mean") {
   z.central.global <- mean(data.global[,3], na.rm = TRUE)
 }
 
-  ## optionally adjust zentral value by user-defined value
+  ## optionally adjust central value by user-defined value
   if(missing(central.value) == FALSE) {
-
     # ## adjust central value for De.add
     central.value <- central.value + De.add
 
@@ -615,9 +613,9 @@ if(centrality[1] == "mean") {
   ## print warning for too small scatter
   if(max(abs(1 / data.global[6])) < 0.02) {
     small.sigma <- TRUE
-    print(paste("Attention, small standardised estimate scatter.",
-                "Toggle off y.ticks?"))
-}
+    message("Attention, small standardised estimate scatter. ",
+            "Toggle off y.ticks?")
+  }
 
   ## read out additional arguments---------------------------------------------
   extraArgs <- list(...)
@@ -629,7 +627,7 @@ if(centrality[1] == "mean") {
 
   if("xlab" %in% names(extraArgs)) {
     if(length(extraArgs$xlab) != 2) {
-      stop("Argmuent xlab is not of length 2!")
+      .throw_error("'xlab' must have length 2")
     } else {xlab <- extraArgs$xlab}
   } else {
     xlab <- c(if(log.z == TRUE) {
@@ -670,7 +668,7 @@ if(centrality[1] == "mean") {
 
   if(limits.x[1] != 0) {
     limits.x[1] <- 0
-    warning("Lower x-axis limit not set to zero, issue corrected!")
+    .throw_warning("Lower x-axis limit not set to zero, corrected")
   }
 
   if("ylim" %in% names(extraArgs)) {
@@ -727,11 +725,7 @@ if(centrality[1] == "mean") {
   show <- if("show" %in% names(extraArgs)) {extraArgs$show} else {TRUE}
   if(show != TRUE) {show <- FALSE}
 
-  fun <- if("fun" %in% names(extraArgs)) {
-    extraArgs$fun
-  } else {
-    FALSE
-  }
+  fun <- if ("fun" %in% names(extraArgs)) extraArgs$fun else FALSE # nocov
 
   ## define auxiliary plot parameters -----------------------------------------
 
@@ -817,9 +811,8 @@ if(centrality[1] == "mean") {
   }
 
   ## subtract De.add from label values
-  if(De.add != 0) {
-    label.z.text <- label.z.text #- De.add
-  }
+  if(De.add != 0)
+    label.z.text <- label.z.text - De.add
 
   labels <- cbind(label.x, label.y, label.z.text)
 
@@ -862,7 +855,7 @@ if(centrality[1] == "mean") {
                             min(abs(ellipse.y - polygon_y_min))]
 
   if(max(polygons[,3]) >= z_2s_upper | max(polygons[,3]) >= z_2s_lower) {
-    print("[plot_RadialPlot] Warning: z-scale touches 2s-polygon. Decrease plot ratio.")
+    .throw_warning("z-scale touches 2s-polygon. Decrease plot ratio.")
   }
 
   ## calculate statistical labels
@@ -913,8 +906,11 @@ if(centrality[1] == "mean") {
     "se.rel.weighted")
 
   for(i in 1:length(data)) {
-    data_to_stats <- data[[i]]
-    data_to_stats$De <- data_to_stats$De - De.add
+    data_to_stats <- data[[i]][,1:2]
+
+    ## remove added De
+    if(log.z) data_to_stats$De <- data_to_stats$De - De.add
+
     statistics <- calc_Statistics(data = data_to_stats)
     De.stats[i,1] <- statistics$weighted$n
     De.stats[i,2] <- statistics$unweighted$mean
@@ -1596,10 +1592,10 @@ label.text[[1]] <- NULL
     }
 
     ##FUN by R Luminescence Team
-    if(fun==TRUE){sTeve()}
+    if (fun == TRUE) sTeve() # nocov
   }
 
-  if(output == TRUE) {
+  if(output) {
     return(list(data = data,
                 data.global = data.global,
                 xlim = limits.x,
