@@ -5,7 +5,7 @@
 #' @details
 #' **How does the import function work?**
 #'
-#' The function uses the [xml] package to parse the file structure. Each
+#' The function uses the `'XML'` package to parse the file structure. Each
 #' sequence is subsequently translated into an [RLum.Analysis-class] object.
 #'
 #' **General structure XSYG format**
@@ -101,7 +101,7 @@
 #' the `txtProgressBar` is also switched off
 #'
 #' @param txtProgressBar [logical] (*with default*):
-#' enables `TRUE` or disables `FALSE` the progression bar during import
+#' enables `TRUE` or disables `FALSE` the progress bar during import
 #'
 #' @return
 #' **Using the option `import = FALSE`**
@@ -120,20 +120,20 @@
 #' @note
 #' This function is a beta version as the XSYG file format is not yet
 #' fully specified. Thus, further file operations (merge, export, write) should
-#' be done using the functions provided with the package [xml].
+#' be done using the functions provided with the package `'XML'`.
 #'
 #' **So far, no image data import is provided!** \cr
 #' Corresponding values in the XSXG file are skipped.
 #'
 #'
-#' @section Function version: 0.6.11
+#' @section Function version: 0.6.12
 #'
 #'
 #' @author
 #' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
 #'
-#' @seealso [xml], [RLum.Analysis-class], [RLum.Data.Curve-class], [approx]
+#' @seealso `'XML'`, [RLum.Analysis-class], [RLum.Data.Curve-class], [approx]
 #'
 #'
 #' @references
@@ -199,12 +199,16 @@ read_XSYG2R <- function(
   if(is(file, "character")) {
     ##If this is not really a path we skip this here
     if (dir.exists(file) & length(dir(file)) > 0) {
-      if(verbose) cat("\n[read_XSYG2R()] Directory detected, trying to extract '*.xsyg' files ...\n")
-      file <-
-        as.list(paste0(file, dir(
-          file, recursive = TRUE, pattern = pattern
-        )))
-
+      if (verbose)
+        message("\n[read_XSYG2R()] Directory detected, trying to extract ",
+                "'*.xsyg' files ...\n")
+      file <- as.list(dir(file, recursive = TRUE, pattern = pattern))
+      if (length(file) == 0) {
+        if (verbose)
+          message("[read_XSYG2R()] No files matching the given pattern ",
+                  "found in directory, NULL returned")
+        return(NULL)
+      }
     }
   }
 
@@ -227,7 +231,6 @@ read_XSYG2R <- function(
 
       } else{
         return(as.data.frame(data.table::rbindlist(temp.return)))
-
       }
 
     } else{
@@ -265,29 +268,41 @@ read_XSYG2R <- function(
 
     ##2nd grep time values
     curve.node <- unlist(strsplit(XML::xmlValue(curve.node), split = ";", fixed = TRUE))
-    curve.node <- unlist(strsplit(curve.node, split = ",", fixed = TRUE), recursive = FALSE)
+    curve.node <- strsplit(curve.node, split = ",", fixed = TRUE)
+    curve.node.time <- as.numeric(vapply(curve.node, function(x) x[1], character(1)))
 
-    curve.node.time <- as.numeric(curve.node[seq(1,length(curve.node),2)])
+    curve.node.time <- as.numeric(vapply(curve.node, function(x) x[1], character(1)))
 
     ##3rd grep count values
-    curve.node.count <- as.character(curve.node[seq(2,length(curve.node),2)])
+    curve.node.count <- vapply(curve.node, function(x) {
+      if(length(x) == 2)
+        x[2]
+      else
+        x[3]
+    }, character(1))
 
     ##remove from pattern...
     curve.node.count <- do.call("gsub", list(pattern="[[]|[]]", replacement=" ",
                                              x=curve.node.count))
 
     ##4th combine to spectrum matrix
-    spectrum.matrix <- matrix(0,length(wavelength),length(curve.node.time))
-    spectrum.matrix <- sapply(1:length(curve.node.time), function(x){
-      as.numeric(unlist(strsplit(curve.node.count[x], "[|]")))
+    spectrum.matrix <- matrix(NA, nrow = length(wavelength), ncol = length(curve.node.time))
+    for(i in 1:length(curve.node.time)) {
+      tmp <- as.numeric(unlist(strsplit(curve.node.count[i], "[|]")))
+      if(length(tmp) == length(wavelength))
+        spectrum.matrix[,i] <- tmp
 
-    })
+    }
+
+    ## remove NA values from matrix
+    id_NA <- colSums(is.na(spectrum.matrix)) != nrow(spectrum.matrix)
+    spectrum.matrix <- spectrum.matrix[, id_NA]
 
     ##change row names (rows are wavelength)
-    rownames(spectrum.matrix) <- round(wavelength, digits=3)
+    rownames(spectrum.matrix) <- round(wavelength, digits = 3)
 
     ##change column names (columns are time/temp values)
-    colnames(spectrum.matrix) <- round(curve.node.time, digits=3)
+    colnames(spectrum.matrix) <- round(curve.node.time[id_NA], digits=3)
 
     return(spectrum.matrix)
   }
@@ -306,7 +321,6 @@ read_XSYG2R <- function(
   if(is(temp, "try-error") == TRUE){
     if(verbose) message("[read_XSYG2R()] XML file not readable, nothing imported!")
     return(NULL)
-
   }
 
   # (2) Further file processing ---------------------------------------------
@@ -331,7 +345,6 @@ read_XSYG2R <- function(
 
     }
 
-
       ##additional option for fastForward == TRUE
       if(fastForward){
 
@@ -340,10 +353,8 @@ read_XSYG2R <- function(
         colnames(temp.sample) <- paste0("sample::", colnames(temp.sample))
         output <- cbind(temp.sequence.header, temp.sample)
 
-
       }else{
         output <-  list(Sample = temp.sample, Sequences = temp.sequence.header)
-
       }
 
     return(output)
@@ -354,7 +365,7 @@ read_XSYG2R <- function(
 
     ##Display output
     if(verbose)
-      paste0("[read_XSYG2R()]\n  Importing: ",file)
+      cat("[read_XSYG2R()]\n  Importing: ", file)
 
     ##PROGRESS BAR
     if(verbose && txtProgressBar){
@@ -388,7 +399,6 @@ read_XSYG2R <- function(
          ##create a fallback, the function should not fail
          if(is.null(temp.sequence.object.recordType) || is.na(temp.sequence.object.recordType)){
            temp.sequence.object.recordType <- "not_set"
-
          }
 
         ##correct record type in depending on the stimulator
@@ -400,9 +410,7 @@ read_XSYG2R <- function(
               XML::xmlSize(temp[[x]][[i]])]])["stimulator"] == "ir_LD_850"){
 
             temp.sequence.object.recordType  <- "IRSL"
-
           }
-
         }
 
         ##loop 3rd level
@@ -426,15 +434,12 @@ read_XSYG2R <- function(
           ##get additional information
           temp.sequence.object.info <- as.list(XML::xmlAttrs(temp.sequence.object.curveValue))
 
-
           ##add stimulator and detector and so on
           temp.sequence.object.info <- c(temp.sequence.object.info,
                                          position = as.integer(as.character(temp.sequence.header["position",])),
                                          name = as.character(temp.sequence.header["name",]))
 
 
-
-
           ## TL curve recalculation ============================================
           if(recalculate.TL.curves){
 
@@ -455,7 +460,6 @@ read_XSYG2R <- function(
                 temp.sequence.object.curveValue.heating.element <- src_get_XSYG_curve_values(XML::xmlValue(
                   temp[[x]][[i]][[3]]))
 
-
               }else{
 
                 temp.sequence.object.curveValue.spectrum <- get_XSYG.spectrum.values(
@@ -468,7 +472,6 @@ read_XSYG2R <- function(
                 ##round values (1 digit is technical resolution of the heating element)
                 temp.sequence.object.curveValue.spectrum.time <- round(
                   temp.sequence.object.curveValue.spectrum.time, digits = 1)
-
               }
 
               #grep values from heating element
@@ -485,7 +488,6 @@ read_XSYG2R <- function(
                       min(temp.sequence.object.curveValue.PMT[,1]) &
                       temp.sequence.object.curveValue.heating.element[,1] <=
                       max(temp.sequence.object.curveValue.PMT[,1]), ,drop = FALSE]
-
               }else{
 
                 #reduce matrix values to values of the detection
@@ -495,12 +497,8 @@ read_XSYG2R <- function(
                       min(temp.sequence.object.curveValue.spectrum.time) &
                       temp.sequence.object.curveValue.heating.element[,1] <=
                       max(temp.sequence.object.curveValue.spectrum.time),]
-
               }
 
-
-
-
               ## calculate corresponding heating rate, this makes only sense
               ## for linear heating, therefore is has to be the maximum value
 
@@ -515,7 +513,6 @@ read_XSYG2R <- function(
                 (heating.rate.values[length(heating.rate.values[,1]), 1] -
                    heating.rate.values[1,1])
 
-
               ##round values
               heating.rate <- round(heating.rate, digits=1)
 
@@ -523,16 +520,12 @@ read_XSYG2R <- function(
               temp.sequence.object.info <- c(temp.sequence.object.info,
                                              RATE = heating.rate)
 
-
               ##PERFORM RECALCULATION
               ##check which object contains more data
-
               if("Spectrometer" %in% temp.sequence.object.detector == FALSE){
-
                 ##CASE (1)
                 if(nrow(temp.sequence.object.curveValue.PMT) >
                    nrow(temp.sequence.object.curveValue.heating.element)){
-
                   temp.sequence.object.curveValue.heating.element.i <- approx(
                     x = temp.sequence.object.curveValue.heating.element[,1],
                     y = temp.sequence.object.curveValue.heating.element[,2],
@@ -567,7 +560,6 @@ read_XSYG2R <- function(
                     temp.sequence.object.curveValue.heating.element[,2]
 
                   count.values <- temp.sequence.object.curveValue.PMT[,2]
-
                 }
 
                 ##combine as matrix
@@ -578,9 +570,7 @@ read_XSYG2R <- function(
                 ##set curve identifier
                 temp.sequence.object.info$curveDescripter <- "Temperature [\u00B0C]; Counts [a.u.]"
 
-
               }else{
-
                 ##CASE (1) here different approach. in contrast to the PMT measurements, as
                 ##         usually the resolution should be much, much lower for such measurements
                 ##         Otherwise we would introduce some pseudo signals, as we have to
@@ -594,7 +584,8 @@ read_XSYG2R <- function(
                     y = temp.sequence.object.curveValue.heating.element[,2],
                     xout = temp.sequence.object.curveValue.spectrum.time,
                     rule = 2,
-                    ties = mean)
+                    ties = mean,
+                    na.rm = FALSE)
 
                   temperature.values <-
                     temp.sequence.object.curveValue.heating.element.i$y
@@ -604,20 +595,14 @@ read_XSYG2R <- function(
 
                     temperature.values[which(duplicated(temperature.values))] <-
                       temperature.values[which(duplicated(temperature.values))]+1
-
-                    warning("[read_XSYG2R()] Temperatures values are found to be duplicated and increased by 1 K")
-
+                    .throw_warning("Temperature values are found to be ",
+                                   "duplicated and increased by 1 K")
                   }
 
-
-
-
                   ##CASE (2)  (equal)
                 }else{
-
                   temperature.values <-
                     temp.sequence.object.curveValue.heating.element[,2]
-
                 }
 
                 ##reset values of the matrix
@@ -626,12 +611,8 @@ read_XSYG2R <- function(
 
                 ##change curve descriptor
                 temp.sequence.object.info$curveDescripter <- "Temperature [\u00B0C]; Wavelength [nm]; Counts [1/ch]"
-
               }
 
-
-
-
             }##endif
           }##endif recalculate.TL.curves == TRUE
 
@@ -640,9 +621,6 @@ read_XSYG2R <- function(
     if("curveType" %in% names(temp.sequence.object.info))
       temp.sequence.object.info[["curveType"]] <- NULL
 
-
-
-
     # Set RLum.Data-objects -----------------------------------------------------------------------
           if("Spectrometer" %in% temp.sequence.object.detector == FALSE){
 
@@ -650,10 +628,8 @@ read_XSYG2R <- function(
 
               temp.sequence.object.curveValue <-
                 src_get_XSYG_curve_values(XML::xmlValue(temp.sequence.object.curveValue))
-
             }
 
-
             set_RLum(
               class = "RLum.Data.Curve",
               originator = "read_XSYG2R",
@@ -671,10 +647,8 @@ read_XSYG2R <- function(
 
               temp.sequence.object.curveValue <-
                 get_XSYG.spectrum.values(temp.sequence.object.curveValue)
-
             }
 
-
             set_RLum(
               class = "RLum.Data.Spectrum",
               originator = "read_XSYG2R",
@@ -684,9 +658,7 @@ read_XSYG2R <- function(
               curveType = temp.sequence.object.curveType,
               data = temp.sequence.object.curveValue,
               info = temp.sequence.object.info)
-
           }
-
         })
 
         }else{
@@ -698,7 +670,6 @@ read_XSYG2R <- function(
       }),
        use.names = FALSE)
 
-
       ##if the XSYG file is broken we get NULL as list element
       if (!is.null(temp.sequence.object)) {
         ##set RLum.Analysis object
@@ -718,19 +689,16 @@ read_XSYG2R <- function(
           setTxtProgressBar(pb, x)
         }
 
-
         ##merge output and return values
         if(fastForward){
           return(temp.sequence.object)
 
         }else{
           return(list(Sequence.Header = temp.sequence.header, Sequence.Object = temp.sequence.object))
-
         }
 
       }else{
         return(temp.sequence.object)
-
       }
 
     })##end loop for sequence list
@@ -738,7 +706,7 @@ read_XSYG2R <- function(
     ##close ProgressBar
     if(verbose && txtProgressBar ){close(pb)}
 
-    ##show output informatioj
+    ##show output information
     if(length(output[sapply(output, is.null)]) == 0){
 
       if(verbose)
@@ -748,12 +716,10 @@ read_XSYG2R <- function(
 
       if(verbose){
         paste("\t >>",XML::xmlSize(temp), " sequence(s) in file.", XML::xmlSize(temp)-length(output[sapply(output, is.null)]), "sequence(s) loaded successfully. \n")
-
       }
 
-
-      warning(paste0(length(output[sapply(output, is.null)])), " incomplete sequence(s) removed.")
-
+      .throw_warning(length(output[sapply(output, is.null)]),
+                     " incomplete sequence(s) removed.")
     }
 
     ##output
@@ -763,5 +729,4 @@ read_XSYG2R <- function(
 
   ##get rid of the NULL elements (as stated before ... invalid files)
   return(output[!sapply(output,is.null)])
-
 }
