@@ -32,7 +32,7 @@
 #' @return A list.
 #'
 #' @author
-#' Christoph Burow, University of Cologne (Germany), Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
+#' Christoph Burow, University of Cologne (Germany), Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
 #' @references
 #' Durcan, J.A., King, G.E., Duller, G.A.T., 2015. DRAC: Dose Rate and Age Calculator for trapped charge dating.
@@ -98,6 +98,9 @@ template_DRAC <- function(
   # 2 - add option to return the DRAC example data set
 
   ## correct incoming to prevent negative values
+  if (!is.numeric(nrow)) {
+    .throw_error("'nrow' must be a positive integer scalar")
+  }
   nrow <- max(1, nrow[1])
 
   ## throw warning
