@@ -1,8 +1,9 @@
-#' Export Risoe.BINfileData into Risø BIN/BINX-file
+#' @title Export Risoe.BINfileData into Risø BIN/BINX-file
 #'
-#' Exports a Risoe.BINfileData object in a *.bin or *.binx file that can be
+#' @description Exports a `Risoe.BINfileData` object in a `*.bin` or `*.binx` file that can be
 #' opened by the Analyst software or other Risø software.
 #'
+#' @details
 #' The structure of the exported binary data follows the data structure
 #' published in the Appendices of the *Analyst* manual p. 42.
 #'
@@ -20,7 +21,7 @@
 #' - `[MAC/LINUX]`: `write_R2BIN("/User/test/Desktop/test.bin")`
 #'
 #' @param version [character] (*optional*):
-#' version number for the output file. If no value is provided the highest
+#' version number for the output file. If no value is provided, the highest
 #' version number from the [Risoe.BINfileData-class] is taken automatically.
 #'
 #' **Note:**
@@ -31,7 +32,7 @@
 #' value to 48. The old position number is appended as comment (e.g., 'OP: 70).
 #' This option accounts for potential compatibility problems with the Analyst software.
 #' It further limits the maximum number of points per curve to 9,999. If a curve contains more
-#' data the curve data got binned using the smallest possible bin width.
+#' data the curve data get binned using the smallest possible bin width.
 #'
 #' @param txtProgressBar [logical] (*with default*):
 #' enables or disables [txtProgressBar].
@@ -48,16 +49,16 @@
 #'
 #' **Warning**
 #'
-#' Although the coding was done carefully it seems that the BIN/BINX-files
+#' Although the coding was done carefully, it seems that the BIN/BINX-files
 #' produced by Risø DA 15/20 TL/OSL readers slightly differ on the byte level.
 #' No obvious differences are observed in the METADATA, however, the
-#' BIN/BINX-file may not fully compatible, at least not similar to the once
+#' BIN/BINX-file may not fully compatible, at least not similar to the ones
 #' directly produced by the Risø readers!
 #'
-#' @section Function version: 0.5.1
+#' @section Function version: 0.5.2
 #'
 #' @author
-#' Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
 #' @note
 #' ROI definitions (introduced in BIN-file version 8) are not supported!
@@ -72,20 +73,16 @@
 #' @keywords IO
 #'
 #' @examples
+#' ##load example dataset
+#' file <- system.file("extdata/BINfile_V8.binx", package = "Luminescence")
+#' temp <- read_BIN2R(file)
 #'
-#' \dontrun{
-#'
-#' ##load exampled dataset
-#' data(ExampleData.BINfileData, envir = environment())
-#'
-#' ##create temporary filepath
+#' ##create temporary file path
 #' ##(for usage replace by own path)
-#' temp_file <- temp_file <- tempfile(pattern = "output", fileext = ".bin")
+#' temp_file <- tempfile(pattern = "output", fileext = ".binx")
 #'
 #' ##export to temporary file path
-#' write_R2BIN(CWOSL.SAR.Data, file = temp_file)
-#'
-#' }
+#' write_R2BIN(temp, file = temp_file)
 #'
 #' @md
 #' @export
@@ -110,10 +107,13 @@ write_R2BIN <- function(
 
   }
 
-  ##check if it fullfills the latest definition ...
+  ## check if it fulfills the latest definition ...
   if(ncol(object@METADATA) != ncol(set_Risoe.BINfileData()@METADATA)){
-    stop("[write_R2BIN()] The number of columns in your slot 'METADATA' does not fit to the latest definition. What you are probably trying to do is to export a Risoe.BINfileData object you generated by your own or you imported with an old package version some time ago. Please re-import the BIN-file using the function read_BIN2R().", call. = FALSE)
-
+    .throw_error("Your Risoe.BINfileData object is not compatible with the ",
+                 "latest specification of this S4-class object. You are ",
+                 "probably trying to export a Risoe.BINfileData from your ",
+                 "workspace you produced manually or with an old version. ",
+                 "Please re-import the BIN-file using function read_BIN2R().")
   }
 
   ##check if input file is of type 'character'
@@ -122,9 +122,7 @@ write_R2BIN <- function(
 
   }
 
-
   # Check Risoe.BINfileData Struture ----------------------------------------
-
   ##check wether the BIN-file DATA slot contains more than 9999 records; needs to be run all the time
   temp_check <- vapply(object@DATA, function(x){
     if(length(x) > 9999){
@@ -144,11 +142,10 @@ write_R2BIN <- function(
     ##BIN data to reduce amount of data if the BIN-file is too long
     object@DATA <- lapply(object@DATA, function(x){
       if(length(x) > 9999){
-
         ##we want to have a minimum binning (smallest number possible)
         bin_width <- ceiling(length(x)/9999)
 
-        ##it should be symatric, thus, remove values
+        ##it should be symmetric, thus, remove values
         if((length(x)/bin_width)%%2 != 0){
           x <- x[-length(x)]
 
@@ -157,7 +154,6 @@ write_R2BIN <- function(
         ##create matrix and return
         colSums(matrix(x, nrow = bin_width))
 
-
       }else{
         x
 
@@ -209,40 +205,27 @@ write_R2BIN <- function(
 
     ##Furthermore, entries length needed to be recalculated
     if(version.original != version){
-
       ##stepping decision
-      header.stepping <- switch(as.character(version),
-                                "08" = 507,
-                                "07" = 447,
-                                "06" = 447,
-                                "05" = 423,
-                                "04" = 272,
-                                "03" = 272)
-
-      object@METADATA[,"LENGTH"] <- sapply(1:nrow(object@METADATA), function(x){
+      header.stepping <- switch(
+        EXPR = as.character(version),
+        "08" = 507,
+        "07" = 447,
+        "06" = 447,
+        "05" = 423,
+        "04" = 272,
+        "03" = 272)
 
+      object@METADATA[,"LENGTH"] <- vapply(1:nrow(object@METADATA), function(x){
         header.stepping + 4 * object@METADATA[x,"NPOINTS"]
 
-      })
+      }, numeric(1))
 
-      object@METADATA[,"PREVIOUS"] <- sapply(1:nrow(object@METADATA), function(x){
+      object@METADATA[,"PREVIOUS"] <- vapply(1:nrow(object@METADATA), function(x){
+        if(x == 1) 0 else header.stepping + 4 * object@METADATA[x-1,"NPOINTS"]
 
-        if(x == 1){
-          0
-        }else{
-          header.stepping + 4 * object@METADATA[x-1,"NPOINTS"]
-        }
-
-      })
+      }, numeric(1))
 
     }
-
-  }
-
-  ##check whether this file can be exported without problems due to the latest specifications
-  if(ncol(object@METADATA) != 80){
-    stop("[write_R2BIN()] Your Risoe.BINfileData object seems not to be compatible with the latest specification of this S4-class object. You are probably trying to export a Risoe.BINfileData from your workspace you produced manually or with an old version.", call. = FALSE)
-
   }
 
   ##Check if the BINfile object contains of unsupported versions
@@ -259,16 +242,13 @@ write_R2BIN <- function(
 
   ##CHECK file name for version == 06 it has to be *.binx and correct for it
   if(version == 05 | version == 06 | version == 07 | version == 08){
-
     ##grep file ending
     temp.file.name <- unlist(strsplit(file, "[:.:]"))
 
     ##*.bin? >> correct to binx
     if(temp.file.name[length(temp.file.name)]=="bin"){
-
       temp.file.name[length(temp.file.name)] <- "binx"
       file <- paste(temp.file.name, collapse=".")
-
     }
   }
 
@@ -276,27 +256,26 @@ write_R2BIN <- function(
   ##SEQUENCE
   if (suppressWarnings(max(nchar(as.character(object@METADATA[,"SEQUENCE"]), type =
                                  "bytes"), na.rm = TRUE)) > 8) {
-    stop("[write_R2BIN()] Value in 'SEQUENCE' exceed storage limit!")
+    stop("[write_R2BIN()] Value in 'SEQUENCE' exceeds storage limit!")
 
   }
 
   ##USER
   if (suppressWarnings(max(nchar(as.character(object@METADATA[,"USER"]), type =
                                  "bytes"), na.rm = TRUE)) > 8) {
-    stop("[write_R2BIN()] 'USER' exceed storage limit!")
+    stop("[write_R2BIN()] 'USER' exceeds storage limit!")
 
   }
 
   ##SAMPLE
   if (suppressWarnings(max(nchar(as.character(object@METADATA[,"SAMPLE"]), type =
                                  "bytes"), na.rm = TRUE)) > 20) {
-    stop("[write_R2BIN()] 'SAMPLE' exceed storage limit!")
+    stop("[write_R2BIN()] 'SAMPLE' exceeds storage limit!")
 
   }
 
   ##enables compatibility to the Analyst as the the max value for POSITION becomes 48
   if(compatibility.mode){
-
     ##just do if position values > 48
     if(max(object@METADATA[,"POSITION"])>48){
 
@@ -325,36 +304,19 @@ write_R2BIN <- function(
 
   }
 
-
   ##COMMENT
   if(max(nchar(as.character(object@METADATA[,"COMMENT"]), type="bytes"))>80){
     stop("[write_R2BIN()] 'COMMENT' exceeds storage limit!", call. = FALSE)
 
   }
 
-
-
-  # Tranlation Matrices -----------------------------------------------------
-
+  # Translation Matrices -----------------------------------------------------
   ##LTYPE
   LTYPE.TranslationMatrix <- matrix(NA, nrow=14, ncol=2)
   LTYPE.TranslationMatrix[,1] <- 0:13
-  LTYPE.TranslationMatrix[,2] <- c("TL",
-                                   "OSL",
-                                   "IRSL",
-                                   "M-IR",
-                                   "M-VIS",
-                                   "TOL",
-                                   "TRPOSL",
-                                   "RIR",
-                                   "RBR",
-                                   "USER",
-                                   "POSL",
-                                   "SGOSL",
-                                   "RL",
-                                   "XRF")
-
-
+  LTYPE.TranslationMatrix[,2] <- c(
+    "TL", "OSL", "IRSL", "M-IR", "M-VIS", "TOL", "TRPOSL", "RIR", "RBR",
+    "USER", "POSL", "SGOSL", "RL", "XRF")
 
   ##DTYPE
   DTYPE.TranslationMatrix <- matrix(NA, nrow=8, ncol=2)
@@ -363,23 +325,15 @@ write_R2BIN <- function(
                                    "Bleach+dose","Natural (Bleach)",
                                    "N+dose (Bleach)","Dose","Background")
 
-
   ##LIGHTSOURCE
   LIGHTSOURCE.TranslationMatrix <- matrix(NA, nrow=8, ncol=2)
   LIGHTSOURCE.TranslationMatrix[,1] <- 0:7
-  LIGHTSOURCE.TranslationMatrix[,2] <- c("None",
-                                         "Lamp",
-                                         "IR diodes/IR Laser",
-                                         "Calibration LED",
-                                         "Blue Diodes",
-                                         "White light",
-                                         "Green laser (single grain)",
-                                         "IR laser (single grain)"
+  LIGHTSOURCE.TranslationMatrix[,2] <- c(
+    "None", "Lamp", "IR diodes/IR Laser", "Calibration LED", "Blue Diodes",
+    "White light", "Green laser (single grain)", "IR laser (single grain)"
   )
 
-
   ##TRANSLATE VALUES IN METADATA
-
   ##LTYPE
   if(is(object@METADATA[1,"LTYPE"], "character") == TRUE |
        is(object@METADATA[1,"LTYPE"], "factor") == TRUE){
@@ -429,29 +383,22 @@ write_R2BIN <- function(
   object@METADATA[,"TAG"] <- ifelse(object@METADATA[,"SEL"] == TRUE, 1, 0)
 
   # SET FILE AND VALUES -----------------------------------------------------
-
   con<-file(file, "wb")
 
   ##get records
   n.records <- length(object@METADATA[,"ID"])
 
   ##output
-  cat(paste("\n[write_R2BIN()]\n\t >> ",file,sep=""), fill=TRUE)
+  message(paste0("[write_R2BIN()]\n\t >> ",file))
 
   ##set progressbar
-  if(txtProgressBar==TRUE){
-    pb<-txtProgressBar(min=0,max=n.records, char="=", style=3)
-  }
-
-
+  if(txtProgressBar)
+    pb <- txtProgressBar(min=0,max=n.records, char="=", style=3)
 
   # LOOP -------------------------------------------------------------------
-
   ID <- 1
-
   if(version == 03 || version == 04){
     ## version 03 and 04
-
     ##start loop for export BIN data
     while(ID<=n.records) {
 
@@ -476,14 +423,12 @@ write_R2BIN <- function(
                size = 2,
                endian="little")
 
-
       ##LTYPE
       writeBin(object@METADATA[ID,"LTYPE"],
                con,
                size = 1,
                endian="little")
 
-
       ##LOW, HIGH, RATE
       writeBin(c(as.double(object@METADATA[ID,"LOW"]),
                  as.double(object@METADATA[ID,"HIGH"]),
@@ -492,7 +437,6 @@ write_R2BIN <- function(
                size = 4,
                endian="little")
 
-
       ##TEMPERATURE, XCOORD, YCOORD, TOLDELAY; TOLON, TOLOFF
       writeBin(c(as.integer(object@METADATA[ID,"TEMPERATURE"]),
                  as.integer(object@METADATA[ID,"XCOORD"]),
@@ -511,8 +455,6 @@ write_R2BIN <- function(
                size = 1,
                endian="little")
 
-
-
       ##TIME
       TIME_SIZE <- nchar(object@METADATA[ID,"TIME"])
       writeBin(as.integer(TIME_SIZE),
@@ -520,7 +462,6 @@ write_R2BIN <- function(
                size = 1,
                endian="little")
 
-
       writeChar(object@METADATA[ID,"TIME"],
                 con,
                 nchars =TIME_SIZE,
@@ -535,26 +476,22 @@ write_R2BIN <- function(
 
       }
 
-
       ##DATE
       writeBin(as.integer(6),
                con,
                size = 1 ,
                endian="little")
 
-
       suppressWarnings(writeChar(as.character(object@METADATA[ID,"DATE"]),
                                  con,
                                  nchars = 6,
                                  useBytes=TRUE,
                                  eos = NULL))
 
-
-
       ##SEQUENCE
-
       ##count number of characters
-      SEQUENCE_SIZE <- as.integer(nchar(as.character(object@METADATA[["SEQUENCE"]][ID]), type = "bytes", keepNA = FALSE))
+      SEQUENCE_SIZE <- as.integer(
+        nchar(as.character(object@METADATA[["SEQUENCE"]][ID]), type = "bytes", keepNA = FALSE))
 
       writeBin(SEQUENCE_SIZE,
                con,
@@ -630,7 +567,6 @@ write_R2BIN <- function(
                size = 1,
                endian="little")
 
-
       ##AN_TEMP, AN_TIME, NORM1, NORM2, NORM2, BG
       writeBin(c(as.double(object@METADATA[ID,"AN_TEMP"]),
                  as.double(object@METADATA[ID,"AN_TIME"]),
@@ -648,8 +584,6 @@ write_R2BIN <- function(
                size = 2,
                endian="little")
 
-
-
       ##SAMPLE
       SAMPLE_SIZE <- as.integer(nchar(as.character(object@METADATA[ID,"SAMPLE"]), type="bytes"))
 
@@ -666,14 +600,12 @@ write_R2BIN <- function(
                size = 1,
                endian="little")
 
-
       writeChar(as.character(object@METADATA[ID,"SAMPLE"]),
                 con,
                 nchars = SAMPLE_SIZE,
                 useBytes=TRUE,
                 eos = NULL)
 
-
       if((20-SAMPLE_SIZE)>0){
         writeBin(raw(length = (20-SAMPLE_SIZE)),
                  con,
@@ -691,7 +623,6 @@ write_R2BIN <- function(
 
       }
 
-
       writeBin(COMMENT_SIZE,
                con,
                size = 1,
@@ -720,14 +651,12 @@ write_R2BIN <- function(
                size = 1,
                endian="little")
 
-
       ##GRAIN
       writeBin(as.integer(object@METADATA[ID,"GRAIN"]),
                con,
                size = 2,
                endian="little")
 
-
       ##LPOWER
       writeBin(as.double(object@METADATA[ID,"LPOWER"]),
                con,
@@ -742,8 +671,6 @@ write_R2BIN <- function(
 
       ##Further distinction needed to fully support format version 03 and 04 separately
       if(version == 03){
-
-
         ##RESERVED 1
         if(length(object@.RESERVED) == 0 || version.original != version){
           writeBin(raw(length=36),
@@ -751,8 +678,7 @@ write_R2BIN <- function(
                    size = 1,
                    endian="little")
         }else{
-
-          writeBin(object@.RESERVED[[ID]][[1]],
+          writeBin(object = object@.RESERVED[[ID]][[1]],
                    con,
                    size = 1,
                    endian="little")
@@ -798,16 +724,13 @@ write_R2BIN <- function(
 
       } else {
         ##version 04
-
-
         ##RESERVED 1
         if(length(object@.RESERVED) == 0 || version.original != version){
           writeBin(raw(length=20),
                    con,
                    size = 1,
                    endian="little")
-        }else{
-
+        } else{
           writeBin(object@.RESERVED[[ID]][[1]],
                    con,
                    size = 1,
@@ -863,17 +786,13 @@ write_R2BIN <- function(
                    size = 1,
                    endian="little")
 
-        }else{
-
+        } else {
           writeBin(object@.RESERVED[[ID]][[2]],
                    con,
                    size = 1,
                    endian="little")
 
         }
-
-
-
       }
       ##DPOINTS
       writeBin(as.integer(unlist(object@DATA[ID])),
@@ -881,24 +800,18 @@ write_R2BIN <- function(
                size = 4,
                endian="little")
 
-
       #SET UNIQUE ID
-      ID<-ID+1
-
+      ID <- ID + 1
       ##update progress bar
-      if(txtProgressBar==TRUE){
-        setTxtProgressBar(pb, ID)
-      }
+      if(txtProgressBar) setTxtProgressBar(pb, ID)
+
     }
   }
   ## ====================================================
   ## version > 06
-
   if(version == 05 | version == 06 | version == 07 | version == 08){
-
     ##start loop for export BIN data
     while(ID<=n.records) {
-
       ##VERSION
       writeBin(as.raw(object@METADATA[ID,"VERSION"]),
                con,
@@ -961,7 +874,6 @@ write_R2BIN <- function(
                 useBytes=TRUE,
                 eos = NULL)
 
-
       if((20-SAMPLE_SIZE)>0){
         writeBin(raw(length = (20-SAMPLE_SIZE)),
                  con,
@@ -991,7 +903,6 @@ write_R2BIN <- function(
                 useBytes=TRUE,
                 eos = NULL)
 
-
       if((80-COMMENT_SIZE)>0){
         writeBin(raw(length = c(80-COMMENT_SIZE)),
                  con,
@@ -1081,7 +992,6 @@ write_R2BIN <- function(
 
       }
 
-
       ##DATE
       writeBin(as.integer(6),
                con,
@@ -1376,7 +1286,6 @@ write_R2BIN <- function(
             endian = "little"
           )
 
-
           ##RESERVED 2
           if(length(object@.RESERVED) == 0 || version.original != version){
             writeBin(raw(length=42),
@@ -1390,27 +1299,20 @@ write_R2BIN <- function(
                      size = 1,
                      endian="little")
           }
-
-
         }
 
-
       }#end if version decision
-
       ##DPOINTS
       writeBin(as.integer(unlist(object@DATA[ID])),
                con,
                size = 4,
                endian="little")
 
-
       #SET UNIQUE ID
       ID <- ID + 1
 
       ##update progress bar
-      if(txtProgressBar==TRUE){
-        setTxtProgressBar(pb, ID)
-      }
+      if(txtProgressBar)  setTxtProgressBar(pb, ID)
 
     }
   }
@@ -1419,9 +1321,8 @@ write_R2BIN <- function(
   close(con)
   #
   # ##close
-  if(txtProgressBar==TRUE){close(pb)}
+  if(txtProgressBar) close(pb)
 
   ##output
-  cat(paste("\t >> ",ID-1,"records have been written successfully!\n\n",paste=""))
-
+  message("\t >> ", ID - 1, " records have been written successfully!\n\n")
 }
