@@ -1,12 +1,12 @@
-#' Export RLum-objects to CSV
+#' @title Export RLum-objects to CSV
 #'
-#' This function exports [RLum-class]-objects to CSV-files using the R function
+#' @description This function exports [RLum-class]-objects to CSV-files using the R function
 #' [utils::write.table]. All [RLum-class]-objects are supported, but the
 #' export is lossy, i.e. the pure numerical values are exported only. Information
 #' that cannot be coerced to a [data.frame] or a [matrix] are discarded as well as
 #' metadata.
 #'
-#' However, in combination with the implemented import functions, nearly every
+#' @details However, in combination with the implemented import functions, nearly every
 #' supported import data format can be exported to CSV-files, this gives a great
 #' deal of freedom in terms of compatibility with other tools.
 #'
@@ -16,7 +16,7 @@
 #' as [list].
 #'
 #' @param object [RLum-class] or a [list] of `RLum` objects (**required**):
-#' objects to be written
+#' objects to be written. Can be a [data.frame] if needed internally.
 #'
 #' @param path [character] (*optional*):
 #' character string naming folder for the output to be written. If nothing
@@ -46,7 +46,7 @@
 #' option `export == FALSE` a list comprising objects of type [data.frame] and [matrix]
 #'
 #'
-#' @section Function version: 0.2.0
+#' @section Function version: 0.2.2
 #'
 #' @author
 #' Sebastian Kreutzer, Geography & Earth Science, Aberystwyth University (United Kingdom)
@@ -85,34 +85,29 @@ write_RLum2CSV <- function(
   ...
 
 ){
-
   # General tests -------------------------------------------------------------------------------
   if(missing(object)){
     stop("[write_RLum2CSV()] input object is missing!", call. = FALSE)
 
   }
 
-
   # Self-call -----------------------------------------------------------------------------------
   ##this option allows to work on a list of RLum-objects
-  if(is.list(object)){
-
+  if(is.list(object) && !is.data.frame(object)){
     ##extent the list of arguments if set
       ##path
       path <- rep(list(path), length = length(object))
 
       ##prefix ... create automatic prefix if nothing is provided
-      if(prefix == ""){
-        prefix <- as.list(paste0("[[",1:length(object),"]]_"))
-
-      }else{
-        prefix <- rep(list(prefix), length = length(object))
-
-      }
+      prefix <- as.list(paste0(prefix[1], "[[",1:length(object),"]]_"))
 
       ##export
       export <- rep(list(export), length = length(object))
 
+      ## write list name to object
+      for (i in 1:length(object))
+        attr(object[[i]], "list_name") <- names(object)[i]
+
     ##execute the self-call function
       temp <- lapply(1:length(object), function(x){
         write_RLum2CSV(
@@ -137,9 +132,7 @@ write_RLum2CSV <- function(
   }
 
   # Integrity tests -----------------------------------------------------------------------------
-
   ##check path
-
     ##if NULL condition
     if(export == TRUE && is.null(path)){
       path <- getwd()
@@ -149,7 +142,7 @@ write_RLum2CSV <- function(
 
     ##non NULL conditon
     if(export == TRUE && !dir.exists(path)){
-      stop("[write_RLum2CSV()] Diretory provided via the argument 'path' does not exist!", call. = FALSE)
+      stop("[write_RLum2CSV()] Directory provided via the argument 'path' does not exist!", call. = FALSE)
 
     }
 
@@ -178,8 +171,7 @@ write_RLum2CSV <- function(
 
       }
 
-    }else if(is(object, "RLum.Results")){
-
+    } else if (is(object, "RLum.Results")){
       ##unlist what ever comes, but do not break structures like matrices, numerics and
       names <- names(object@data)
 
@@ -218,13 +210,20 @@ write_RLum2CSV <- function(
       ##adjust the names
       names(object_list) <- paste0(1:length(object_list),"_",names(object_list))
 
-
-    }else{
-      try(stop("[write_RLum2CSV()] One particular RLum-object is not yet supported! NULL returned!", call. = FALSE))
+    } else {
+      # nocov start
+      message("[write_RLum2CSV()] Error: One particular RLum-object ",
+              "is not yet supported, NULL returned")
       return(NULL)
-
+      # nocov end
     }
 
+  } else if (inherits(object, "data.frame")) {
+    object_list <- list(object)
+    if(!is.null(attr(object, "filename"))) filename <- attr(object, "filename") else  filename <- ""
+
+    names(object_list) <- paste0("conv_", attr(object, "list_name"), filename)
+
   }else{
    stop("[write_RLum2CSV()] Object needs to be a member of the object class RLum!", call. = FALSE)
 
@@ -232,7 +231,6 @@ write_RLum2CSV <- function(
 
   # Export --------------------------------------------------------------------------------------
   if(export){
-
     ##set export settings for write.table
     export_settings.default <- list(
       append = FALSE,
@@ -255,7 +253,7 @@ write_RLum2CSV <- function(
     for(i in 1:length(object_list)){
       utils::write.table(
         x = object_list[[i]],
-        file = paste0(path,"/",prefix, names(object_list)[i],".csv"),
+        file = paste0(path,"/", prefix, names(object_list)[i],".csv"),
         append = export_settings$append,
         quote =  export_settings$quote,
         sep =  export_settings$sep,
@@ -269,7 +267,6 @@ write_RLum2CSV <- function(
 
     }
 
-
   }else{
     return(object_list)
 
