@@ -1,5 +1,3 @@
-context("calc_Statistics")
-
 ## load example data
 data(ExampleData.DeValues, envir = environment())
 
@@ -12,13 +10,18 @@ temp_RLum <- set_RLum(class = "RLum.Results", data = list(data = ExampleData.DeV
 
 test_that("check class and length of output", {
   testthat::skip_on_cran()
-  expect_equal(is(temp), c("list", "vector"))
+
+  expect_type(temp, "list")
   expect_equal(length(temp), 3)
 
 })
 
 test_that("Test certain input scenarios", {
-  expect_is(calc_Statistics(temp_RLum), "list")
+  expect_type(calc_Statistics(temp_RLum), "list")
+
+  df <- ExampleData.DeValues$BT998
+  df[, 2] <- NULL
+  expect_warning(calc_Statistics(df))
 
   df <- ExampleData.DeValues$BT998
   df[,2] <- 0
@@ -26,8 +29,6 @@ test_that("Test certain input scenarios", {
 
   df <- ExampleData.DeValues$BT998
   expect_silent(calc_Statistics(df, weight.calc = "reciprocal"))
-
-
 })
 
 
@@ -46,9 +47,10 @@ test_that("check error messages", {
 
 test_that("check weighted values from output", {
   testthat::skip_on_cran()
+
   expect_equal(temp$weighted$n, 25)
-  expect_equal(sum(unlist(temp_alt1)),24535.72)
-  expect_equal(sum(unlist(temp_alt2)),24534.1)
+  expect_equal(sum(unlist(temp_alt1)),18558.37)
+  expect_equal(sum(unlist(temp_alt2)),18555.994)
   expect_equal(round(temp$weighted$mean, digits = 3), 2896.036)
   expect_equal(round(temp$weighted$median, digits = 2), 2884.46)
   expect_equal(round(temp$weighted$sd.abs, digits = 4), 240.2228)
@@ -86,8 +88,8 @@ test_that("check MCM values from output", {
   expect_equal(round(temp$MCM$sd.rel, digits = 6), 9.999137)
   expect_equal(round(temp$MCM$se.abs, digits = 5), 59.01474)
   expect_equal(round(temp$MCM$se.rel, digits = 6), 1.999827)
-  expect_equal(round(temp$MCM$skewness, digits = 3), 1286.082)
-  expect_equal(round(temp$MCM$kurtosis, digits = 3), 4757.097)
+  expect_equal(round(temp$MCM$skewness, digits = 3), 1.286)
+  expect_equal(round(temp$MCM$kurtosis, digits = 3), 4.757)
 
 
 })
