@@ -1,9 +1,10 @@
 test_that("basic checks", {
   testthat::skip_on_cran()
-  local_edition(3)
 
   ## template
+  SW({
   template <- expect_s3_class(convert_Concentration2DoseRate(), "data.frame")
+  })
 
   ## break function
   expect_error(convert_Concentration2DoseRate(input = "fail"),
