@@ -1,6 +1,5 @@
 test_that("test conversion from single grain data to multiple grain data", {
   testthat::skip_on_cran()
-  local_edition(3)
 
   ## load example dataset
   data(ExampleData.BINfileData, envir = environment())
@@ -15,12 +14,17 @@ test_that("test conversion from single grain data to multiple grain data", {
 
   ## test write option
   ## create environment
-  tmp <- paste0(tempdir(), "_test.bin")
+  dir <- tempdir()
+  tmp <- paste0(dir, "/test.bin")
+  SW({
   write_file_test <- write_R2BIN(
-  read_BIN2R(file = "https://github.com/R-Lum/Luminescence/raw/master/tests/testdata/BINfile_V4.bin"),
-  tmp)
-
-  expect_s4_class(convert_SG2MG(tmp, write_file = TRUE, txtProgressBar = FALSE), "Risoe.BINfileData")
+      read_BIN2R(file = test_path("_data/BINfile_V4.bin")),
+      file = tmp)
 
+  expect_s4_class(convert_SG2MG(tmp, write_file = TRUE, txtProgressBar = FALSE),
+                  "Risoe.BINfileData")
+  })
 
+  ##clear temp folder otherwise we have a problem with the CRAN check
+  file.remove(list.files(dir,pattern = ".bin", full.names = TRUE))
 })
